@@ -30,6 +30,8 @@
 # the default location, docbook.xsl in
 # $HOME/docbook-xsl-1.72.0/html/docbook.xsl.
 #
+# To build for Android, set compiler="cross-android".
+#
 # The source code for the libraries is downloaded from Debian and Ubuntu
 # repositories. If the files are no longer available, use a later version,
 # it should still work.
@@ -49,14 +51,14 @@ test ${kernel:0:5} = "MINGW" && kernel="MINGW"
 
 compiler="gcc"
 
-qt_version=5.5.0
+qt_version=5.5.1
 zlib_version=1.2.8
 zlib_patchlevel=2
 libogg_version=1.3.2
 libogg_patchlevel=1
 libvorbis_version=1.3.4
 libvorbis_patchlevel=3
-ffmpeg_version=2.8
+ffmpeg_version=2.8.2
 ffmpeg_patchlevel=1
 #libav_version=11.4
 #libav_patchlevel=2
@@ -64,11 +66,11 @@ libflac_version=1.3.1
 libflac_patchlevel=4
 id3lib_version=3.8.3
 id3lib_patchlevel=16.2
-taglib_version=1.10beta
+taglib_version=1.10
 chromaprint_version=1.2
 chromaprint_patchlevel=1
 mp4v2_version=2.0.0
-mp4v2_patchlevel=3
+mp4v2_patchlevel=4
 
 # Uncomment for debug build
 #ENABLE_DEBUG=--enable-debug
@@ -2163,7 +2165,42 @@ fi
 
 test -d bin || mkdir bin
 
-if test "$compiler" = "msvc"; then
+if test "$compiler" = "cross-android"; then
+
+echo "### Building taglib"
+
+_android_sdk_root=/opt/android/sdk
+_android_ndk_root=$_android_sdk_root/ndk-bundle
+_android_abi=armeabi-v7a
+_android_toolchain_prefix=
+_android_qt_root=/opt/Qt/5.5/android_armv7
+#_android_abi=x86
+#_android_toolchain_prefix=x86
+#_android_qt_root=/opt/Qt/5.5/android_x86
+test -d buildroot || mkdir buildroot
+_buildroot=$(pwd)/buildroot
+
+cd taglib-${taglib_version}/
+cmake -DWITH_ASF=ON -DWITH_MP4=ON -DENABLE_STATIC=ON -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=$_buildroot/usr/local -DANDROID_NDK=$_android_ndk_root -DANDROID_ABI=$_android_abi -DANDROID_TOOLCHAIN_PREFIX=$_android_toolchain_prefix -DCMAKE_TOOLCHAIN_FILE=../../kid3/android/qt-android-cmake/toolchain/android.toolchain.cmake
+make install
+cd ..
+
+if ! test -d kid3; then
+  mkdir kid3
+  cat >kid3/build.sh <<EOF
+_java_root=/usr/lib/jvm/java-7-openjdk-amd64
+_android_sdk_root=$_android_sdk_root
+_android_ndk_root=$_android_ndk_root
+_android_abi=$_android_abi
+_android_toolchain_prefix=$_android_toolchain_prefix
+_android_qt_root=$_android_qt_root
+_buildprefix=\$(cd ..; pwd)/buildroot/usr/local
+cmake -GNinja -DJAVA_HOME=\$_java_root -DQT_ANDROID_SDK_ROOT=\$_android_sdk_root -DANDROID_NDK=\$_android_ndk_root -DQT_ANDROID_ANT=/usr/bin/ant -DAPK_ALL_TARGET=OFF -DANDROID_ABI=\$_android_abi -DANDROID_TOOLCHAIN_PREFIX=\$_android_toolchain_prefix -DCMAKE_TOOLCHAIN_FILE=../../kid3/android/qt-android-cmake/toolchain/android.toolchain.cmake -DQT_QMAKE_EXECUTABLE=\$_android_qt_root/bin/qmake -DCMAKE_BUILD_TYPE=Release -DDOCBOOK_XSL_DIR=/usr/share/xml/docbook/stylesheet/nwalsh -DPERL_EXECUTABLE=/usr/bin/perl -DXSLTPROC=/usr/bin/xsltproc -DGZIP_EXECUTABLE=/bin/gzip -DTAGLIBCONFIG_EXECUTABLE=\$_buildprefix/bin/taglib-config ../../kid3
+EOF
+  chmod +x kid3/build.sh
+fi
+
+elif test "$compiler" = "msvc"; then
 
 echo "### Building libogg"
 
@@ -2241,7 +2278,7 @@ if test "$1" = "clean"; then
     rm -rf $d/inst
   done
 fi
-  
+
 if test ! -d zlib-${zlib_version}/inst; then
 echo "### Building zlib"
 
@@ -2651,24 +2688,23 @@ EOF
     fi
     chmod +x kid3/build.sh
   fi
-elif test $kernel = "Darwin"; then
-  sudo chmod go+w ${BUILDROOT}usr/local
 fi
-
-tar xmzf bin/zlib-${zlib_version}.tgz -C $BUILDROOT
-tar xmzf bin/libogg-${libogg_version}.tgz -C $BUILDROOT
-tar xmzf bin/libvorbis-${libvorbis_version}.tgz -C $BUILDROOT
-tar xmzf bin/flac-${libflac_version}.tgz -C $BUILDROOT
-tar xmzf bin/id3lib-${id3lib_version}.tgz -C $BUILDROOT
-tar xmzf bin/taglib-${taglib_version}.tgz -C $BUILDROOT
-tar xmzf bin/${ffmpeg_dir}.tgz -C $BUILDROOT
-tar xmzf bin/chromaprint-${chromaprint_version}.tgz -C $BUILDROOT
-tar xmzf bin/mp4v2-${mp4v2_version}.tgz -C $BUILDROOT
-
 if test $kernel = "Darwin"; then
-  sudo chmod go-w ${BUILDROOT}usr/local
+  tar_cmd="sudo tar xmozf"
+else
+  tar_cmd="tar xmzf"
 fi
 
+${tar_cmd} bin/zlib-${zlib_version}.tgz -C $BUILDROOT
+${tar_cmd} bin/libogg-${libogg_version}.tgz -C $BUILDROOT
+${tar_cmd} bin/libvorbis-${libvorbis_version}.tgz -C $BUILDROOT
+${tar_cmd} bin/flac-${libflac_version}.tgz -C $BUILDROOT
+${tar_cmd} bin/id3lib-${id3lib_version}.tgz -C $BUILDROOT
+${tar_cmd} bin/taglib-${taglib_version}.tgz -C $BUILDROOT
+${tar_cmd} bin/${ffmpeg_dir}.tgz -C $BUILDROOT
+${tar_cmd} bin/chromaprint-${chromaprint_version}.tgz -C $BUILDROOT
+${tar_cmd} bin/mp4v2-${mp4v2_version}.tgz -C $BUILDROOT
+
 fi
 
 echo "### Built successfully"
