@@ -29,7 +29,6 @@
 
 #include <QObject>
 #include "trackdata.h"
-#include "batchimportprofile.h"
 #include "filefilter.h"
 #include "config.h"
 
@@ -196,8 +195,8 @@ protected:
    * @param useDefault if true use cli()->tagMask() if no parameter found
    * @return tag versions.
    */
-  TrackData::TagVersion getTagMaskParameter(int nr,
-                                            bool useDefault = true) const;
+  Frame::TagVersion getTagMaskParameter(int nr,
+                                        bool useDefault = true) const;
 
   /**
    * Show usage of command.
@@ -265,10 +264,6 @@ protected:
   virtual void startCommand();
   virtual void connectResultSignal();
   virtual void disconnectResultSignal();
-
-private slots:
-  void onDirectoryOpened(const QPersistentModelIndex& dirIndex,
-                         const QList<QPersistentModelIndex>& fileIndexes);
 };
 
 
@@ -392,11 +387,7 @@ protected:
   virtual void disconnectResultSignal();
 
 private slots:
-  void onReportImportEvent(BatchImportProfile::ImportEventType type,
-                           const QString& text);
-
-private:
-  BatchImportProfile m_profile;
+  void onReportImportEvent(int type, const QString& text);
 };
 
 /** Download album cover art. */
@@ -515,8 +506,7 @@ protected:
   virtual void disconnectResultSignal();
 
 private slots:
-  void onFileFiltered(FileFilter::FilterEventType type,
-                      const QString& fileName);
+  void onFileFiltered(int type, const QString& fileName);
 };
 
 /** Convert ID3v2.3 to ID3v2.4. */
