@@ -27,6 +27,9 @@
 #include "kdeconfigdialog.h"
 #include "contexthelp.h"
 #include "configdialogpages.h"
+#if QT_VERSION >= 0x050000
+#include <QPushButton>
+#endif
 
 /**
  * Constructor.
@@ -51,12 +54,25 @@ KdeConfigDialog::KdeConfigDialog(QWidget* parent, QString& caption,
   addPage(m_pages->createPluginsPage(), tr("Plugins"), QLatin1String("preferences-plugin"));
 
 #if QT_VERSION >= 0x050000
-  setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel |
+  setStandardButtons(QDialogButtonBox::RestoreDefaults |
+                     QDialogButtonBox::Ok | QDialogButtonBox::Cancel |
                      QDialogButtonBox::Help);
+  if (const QDialogButtonBox* buttons = buttonBox()) {
+    if (QPushButton* helpButton = buttons->button(QDialogButtonBox::Help)) {
+      connect(helpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
+    }
+    if (QPushButton* defaultsButton =
+        buttons->button(QDialogButtonBox::RestoreDefaults)) {
+      connect(defaultsButton, SIGNAL(clicked()),
+              m_pages, SLOT(setDefaultConfig()));
+    }
+  }
 #else
-  setButtons(Ok | Cancel | Help);
-#endif
+  setButtons(Default | Ok | Cancel | Help);
+  enableButton(Default, true);
+  connect(this, SIGNAL(defaultClicked()), m_pages, SLOT(setDefaultConfig()));
   setHelp(QLatin1String("configure-kid3"));
+#endif
 }
 
 /**
@@ -88,3 +104,14 @@ void KdeConfigDialog::slotHelp()
 {
   ContextHelp::displayHelp(QLatin1String("configure-kid3"));
 }
+
+/**
+ * Returns whether the current state of the dialog is
+ * the same as the default configuration.
+ * @return false
+ */
+bool KdeConfigDialog::isDefault()
+{
+  // The "Defaults" button shall be always enabled.
+  return false;
+}
