@@ -27,7 +27,12 @@
 #ifndef KDEMAINWINDOW_H
 #define KDEMAINWINDOW_H
 
+#include <QtGlobal>
+#if QT_VERSION >= 0x050000
+#include <KXmlGuiWindow>
+#else
 #include <kxmlguiwindow.h>
+#endif
 #include "basemainwindow.h"
 
 class QAction;
@@ -130,7 +135,11 @@ private slots:
    *
    * @param url URL of directory to open
    */
+#if QT_VERSION >= 0x050000
+  void slotFileOpenRecentUrl(const QUrl& url);
+#else
   void slotFileOpenRecentUrl(const KUrl& url);
+#endif
 
   /**
    * Shortcuts configuration.
@@ -150,8 +159,6 @@ private slots:
 private:
   /** Actions */
   KRecentFilesAction* m_fileOpenRecent;
-  KToggleAction* m_viewToolBar;
-  KToggleAction* m_viewStatusBar;
   KToggleAction* m_settingsAutoHideTags;
   KToggleAction* m_settingsShowHidePicture;
 };
