@@ -27,12 +27,13 @@
 #include "kdeplatformtools.h"
 #include <QtConfig>
 #if QT_VERSION >= 0x050000
-#include <KIO/CopyJob>
 #include <KHelpClient>
 #include <KMessageBox>
 #include <KConfig>
 #include <QUrl>
 #include <QFileDialog>
+#include "mainwindowconfig.h"
+#include "coreplatformtools.h"
 
 #define KUrl QUrl
 #define KIcon QIcon::fromTheme
@@ -93,12 +94,12 @@ ISettings* KdePlatformTools::applicationSettings()
  */
 bool KdePlatformTools::moveToTrash(const QString& path) const
 {
+#if QT_VERSION >= 0x050000
+  return CorePlatformTools::moveFileToTrash(path);
+#else
   KUrl src;
   src.setPath(path);
   KIO::Job* job = KIO::trash(src);
-#if QT_VERSION >= 0x050000
-  return job->exec();
-#else
   return KIO::NetAccess::synchronousRun(job, 0);
 #endif
 }
@@ -132,6 +133,9 @@ QIcon KdePlatformTools::iconFromTheme(const QString& name) const
 QString KdePlatformTools::fileDialogNameFilter(
     const QList<QPair<QString, QString> >& nameFilters) const
 {
+#if QT_VERSION >= 0x050000
+  return ICorePlatformTools::qtFileDialogNameFilter(nameFilters);
+#else
   QString filter;
   for (QList<QPair<QString, QString> >::const_iterator it =
        nameFilters.constBegin();
@@ -150,6 +154,7 @@ QString KdePlatformTools::fileDialogNameFilter(
     }
   }
   return filter;
+#endif
 }
 
 /**
@@ -159,12 +164,16 @@ QString KdePlatformTools::fileDialogNameFilter(
  */
 QString KdePlatformTools::getNameFilterPatterns(const QString& nameFilter) const
 {
+#if QT_VERSION >= 0x050000
+  return ICorePlatformTools::qtNameFilterPatterns(nameFilter);
+#else
   if (nameFilter.startsWith(QLatin1Char('*'))) {
     int end = nameFilter.indexOf(QLatin1Char('|'));
     return end != -1 ? nameFilter.left(end) : nameFilter;
   } else {
     return QString();
   }
+#endif
 }
 
 /**
@@ -242,14 +251,16 @@ QString KdePlatformTools::getOpenFileName(QWidget* parent,
 {
 #if QT_VERSION >= 0x050000
   return QFileDialog::getOpenFileName(
-        parent, caption, dir, filter, selectedFilter);
+        parent, caption, dir, filter, selectedFilter,
+        MainWindowConfig::instance().dontUseNativeDialogs()
+        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0));
 #else
   if (selectedFilter) {
     QString selectedFile;
     KFileDialog diag(dir, filter, parent);
+    const char* const openStr = QT_TRANSLATE_NOOP("@default", "Open");
     diag.setWindowTitle(caption.isEmpty()
-                        ? QCoreApplication::translate("@default",
-                              QT_TRANSLATE_NOOP("@default", "Open"))
+                        ? QCoreApplication::translate("@default", openStr)
                         : caption);
     if (diag.exec() == QDialog::Accepted) {
       selectedFile = diag.selectedFile();
@@ -277,14 +288,16 @@ QStringList KdePlatformTools::getOpenFileNames(QWidget* parent,
 {
 #if QT_VERSION >= 0x050000
   return QFileDialog::getOpenFileNames(
-        parent, caption, dir, filter, selectedFilter);
+        parent, caption, dir, filter, selectedFilter,
+        MainWindowConfig::instance().dontUseNativeDialogs()
+        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0));
 #else
   if (selectedFilter) {
     QStringList selectedFiles;
     KFileDialog diag(dir, filter, parent);
+    const char* const openStr = QT_TRANSLATE_NOOP("@default", "Open");
     diag.setWindowTitle(caption.isEmpty()
-                        ? QCoreApplication::translate("@default",
-                              QT_TRANSLATE_NOOP("@default", "Open"))
+                        ? QCoreApplication::translate("@default", openStr)
                         : caption);
     diag.setMode(KFile::Files | KFile::LocalOnly);
     if (diag.exec() == QDialog::Accepted) {
@@ -313,15 +326,17 @@ QString KdePlatformTools::getSaveFileName(QWidget* parent,
 {
 #if QT_VERSION >= 0x050000
   return QFileDialog::getSaveFileName(
-        parent, caption, dir, filter, selectedFilter);
+        parent, caption, dir, filter, selectedFilter,
+        MainWindowConfig::instance().dontUseNativeDialogs()
+        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0));
 #else
   if (selectedFilter) {
     QString selectedFile;
     KFileDialog diag(dir, filter, parent);
     diag.setOperationMode(KFileDialog::Saving);
+    const char* const saveAsStr = QT_TRANSLATE_NOOP("@default", "Save As");
     diag.setWindowTitle(caption.isEmpty()
-                        ? QCoreApplication::translate("@default",
-                              QT_TRANSLATE_NOOP("@default", "Save As"))
+                        ? QCoreApplication::translate("@default", saveAsStr)
                         : caption);
     if (diag.exec() == QDialog::Accepted) {
       selectedFile = diag.selectedFile();
@@ -346,7 +361,9 @@ QString KdePlatformTools::getExistingDirectory(QWidget* parent,
 {
 #if QT_VERSION >= 0x050000
   return QFileDialog::getExistingDirectory(parent, caption, startDir,
-                                           QFileDialog::ShowDirsOnly);
+      MainWindowConfig::instance().dontUseNativeDialogs()
+      ? QFileDialog::ShowDirsOnly | QFileDialog::DontUseNativeDialog
+      : QFileDialog::ShowDirsOnly);
 #else
   return KFileDialog::getExistingDirectory(startDir, parent, caption);
 #endif
