@@ -61,6 +61,15 @@ public:
    */
   virtual ~HttpClient();
 
+  /**
+   * Send a HTTP GET request.
+   *
+   * @param url URL
+   * @param headers optional raw headers to send
+   */
+  void sendRequest(const QUrl& url,
+                   const RawHeaderMap& headers = RawHeaderMap());
+
   /**
    * Send a HTTP GET request.
    *
@@ -181,8 +190,7 @@ private:
   QTimer* m_requestTimer;
   /** Context for delayedSendRequest() */
   struct {
-    QString server;
-    QString path;
+    QUrl url;
     RawHeaderMap headers;
   } m_delayedSendRequestContext;
 
