@@ -118,6 +118,12 @@ public:
 #endif
 
 signals:
+  /**
+   * Emitted before a file starts playing.
+   * @param filePath path to file
+   */
+  void aboutToPlay(const QString& filePath);
+
   /**
    * Emitted when the current track is changed.
    * @param filePath path of currently played audio file
