@@ -287,7 +287,9 @@ QList<UserActionsConfig::MenuCommand> CommandsTableModel::getCommandList() const
   for (QList<UserActionsConfig::MenuCommand>::const_iterator it = m_cmdList.constBegin();
        it != m_cmdList.constEnd();
        ++it) {
-    if (!it->getName().isEmpty()) {
+    if (!it->getName().isEmpty() ||
+        it->getCommand() == QLatin1String("@separator") ||
+        it->getCommand() == QLatin1String("@endmenu")) {
       cmdList.append(*it);
     }
   }
