@@ -64,16 +64,11 @@ public:
    */
   virtual void clearAborted();
 
-  /**
-   * Abort operation.
-   */
-  virtual void abort();
-
   /**
    * Set version of tags used to get rename information.
    * @param tagVersion tag version
    */
-  void setTagVersion(TrackData::TagVersion tagVersion) {
+  void setTagVersion(Frame::TagVersion tagVersion) {
     m_tagVersion = tagVersion;
   }
 
@@ -142,6 +137,12 @@ public:
    */
   QString getDirName() const { return m_dirName; }
 
+public slots:
+  /**
+   * Abort operation.
+   */
+  virtual void abort();
+
 signals:
   /**
    * Is emitted after an action has been scheduled.
@@ -293,7 +294,7 @@ private:
   QStringList describeAction(const RenameAction& action) const;
 
   RenameActionList m_actions;
-  TrackData::TagVersion m_tagVersion;
+  Frame::TagVersion m_tagVersion;
   QString m_format;
   QString m_dirName;
   bool m_aborted;
