@@ -29,6 +29,7 @@
 #include <QTimer>
 #include "taggedfileiconprovider.h"
 #include "itaggedfilefactory.h"
+#include "tagconfig.h"
 #include "config.h"
 
 /** Only defined for generation of translation files */
@@ -45,6 +46,22 @@
 
 QList<ITaggedFileFactory*> FileProxyModel::s_taggedFileFactories;
 
+namespace {
+
+QHash<int,QByteArray> getRoleHash()
+{
+  QHash<int, QByteArray> roles;
+  roles[QFileSystemModel::FileNameRole] = "fileName";
+  roles[QFileSystemModel::FilePathRole] = "filePath";
+  roles[FileProxyModel::IconIdRole] = "iconId";
+  roles[FileProxyModel::TruncatedRole] = "truncated";
+  roles[FileProxyModel::IsDirRole] = "isDir";
+  roles[Qt::CheckStateRole] = "checkState";
+  return roles;
+}
+
+}
+
 /**
  * Constructor.
  *
@@ -53,7 +70,7 @@ QList<ITaggedFileFactory*> FileProxyModel::s_taggedFileFactories;
 FileProxyModel::FileProxyModel(QObject* parent) : QSortFilterProxyModel(parent),
   m_iconProvider(new TaggedFileIconProvider), m_fsModel(0),
   m_loadTimer(new QTimer(this)), m_sortTimer(new QTimer(this)),
-  m_isLoading(false)
+  m_numModifiedFiles(0), m_isLoading(false)
 {
   setObjectName(QLatin1String("FileProxyModel"));
   connect(this, SIGNAL(rowsInserted(QModelIndex,int,int)),
@@ -64,8 +81,32 @@ FileProxyModel::FileProxyModel(QObject* parent) : QSortFilterProxyModel(parent),
   m_sortTimer->setSingleShot(true);
   m_sortTimer->setInterval(100);
   connect(m_sortTimer, SIGNAL(timeout()), this, SLOT(emitSortingFinished()));
+#if QT_VERSION < 0x050000
+  setRoleNames(getRoleHash());
+#endif
 }
 
+/**
+ * Destructor.
+ */
+FileProxyModel::~FileProxyModel()
+{
+  clearTaggedFileStore();
+  delete m_iconProvider;
+}
+
+#if QT_VERSION >= 0x050000
+/**
+ * Map role identifiers to role property names in scripting languages.
+ * @return hash mapping role identifiers to names.
+ */
+QHash<int,QByteArray> FileProxyModel::roleNames() const
+{
+  static QHash<int, QByteArray> roles = getRoleHash();
+  return roles;
+}
+#endif
+
 /**
  * Get file information of model index.
  * @return file information
@@ -92,6 +133,19 @@ QString FileProxyModel::filePath(const QModelIndex& index) const
   return QString();
 }
 
+/**
+ * Get file name of model index.
+ * @return name of file or directory
+ */
+QString FileProxyModel::fileName(const QModelIndex& index) const
+{
+  if (m_fsModel) {
+    QModelIndex sourceIndex(mapToSource(index));
+    return m_fsModel->fileName(sourceIndex);
+  }
+  return QString();
+}
+
 /**
  * Check if model index represents directory.
  * @return true if directory
@@ -165,15 +219,6 @@ void FileProxyModel::updateInsertedRows(const QModelIndex& parent,
   }
 }
 
-/**
- * Destructor.
- */
-FileProxyModel::~FileProxyModel()
-{
-  clearTaggedFileStore();
-  delete m_iconProvider;
-}
-
 /**
  * Check if row should be included in model.
  *
@@ -230,6 +275,19 @@ QVariant FileProxyModel::data(const QModelIndex& index, int role) const
         if (color.isValid())
           return color;
       }
+    } else if (role == IconIdRole && index.column() == 0) {
+      TaggedFile* taggedFile = m_taggedFiles.value(index, 0);
+      return taggedFile
+          ? m_iconProvider->iconIdForTaggedFile(taggedFile)
+          : QByteArray("");
+    } else if (role == TruncatedRole && index.column() == 0) {
+      TaggedFile* taggedFile = m_taggedFiles.value(index, 0);
+      return taggedFile &&
+          ((TagConfig::instance().markTruncations() &&
+            taggedFile->getTruncationFlags() != 0) ||
+           taggedFile->isMarked());
+    } else if (role == IsDirRole && index.column() == 0) {
+      return isDir(index);
     }
   }
   return QSortFilterProxyModel::data(index, role);
@@ -290,6 +348,9 @@ void FileProxyModel::setSourceModel(QAbstractItemModel* sourceModel)
     }
   }
   QSortFilterProxyModel::setSourceModel(sourceModel);
+#if QT_VERSION < 0x050000
+  setRoleNames(getRoleHash());
+#endif
 }
 
 /**
@@ -407,18 +468,6 @@ void FileProxyModel::applyFilteringOutIndexes()
   invalidateFilter();
 }
 
-/**
- * Emit dataChanged() to the model to force an update of the connected views,
- * e.g. when the modification state changes.
-  * @param topLeft top left item changed
-  * @param bottomRight bottom right item changed
- */
-void FileProxyModel::emitDataChanged(const QModelIndex& topLeft,
-                                     const QModelIndex& bottomRight)
-{
-  emit dataChanged(topLeft, bottomRight);
-}
-
 /**
  * Retrieve tagged file for an index.
  * @param index model index
@@ -474,8 +523,7 @@ void FileProxyModel::initTaggedFileData(const QModelIndex& index) {
   if (dat.isValid() || isDir(index))
     return;
 
-  QFileInfo info = fileInfo(index);
-  dat.setValue(createTaggedFile(info.path(), info.fileName(), index));
+  dat.setValue(createTaggedFile(fileName(index), index));
   setData(index, dat, TaggedFileRole);
 }
 
@@ -543,7 +591,7 @@ TaggedFile* FileProxyModel::readWithId3V24(TaggedFile* taggedFile)
 {
   const QPersistentModelIndex& index = taggedFile->getIndex();
   if (TaggedFile* tagLibFile = createTaggedFile(TaggedFile::TF_ID3v24,
-          taggedFile->getDirname(), taggedFile->getFilename(), index)) {
+          taggedFile->getFilename(), index)) {
     if (index.isValid()) {
       QVariant data;
       data.setValue(tagLibFile);
@@ -564,7 +612,6 @@ TaggedFile* FileProxyModel::readWithId3V24(TaggedFile* taggedFile)
  * Create a tagged file with a given feature.
  *
  * @param feature tagged file feature
- * @param dirName directory name
  * @param fileName filename
  * @param idx model index
  *
@@ -572,13 +619,13 @@ TaggedFile* FileProxyModel::readWithId3V24(TaggedFile* taggedFile)
  */
 TaggedFile* FileProxyModel::createTaggedFile(
     TaggedFile::Feature feature,
-    const QString& dirName, const QString& fileName,
+    const QString& fileName,
     const QPersistentModelIndex& idx) {
   TaggedFile* taggedFile = 0;
   foreach (ITaggedFileFactory* factory, s_taggedFileFactories) {
     foreach (const QString& key, factory->taggedFileKeys()) {
       if ((factory->taggedFileFeatures(key) & feature) != 0 &&
-          (taggedFile = factory->createTaggedFile(key, dirName, fileName, idx,
+          (taggedFile = factory->createTaggedFile(key, fileName, idx,
                                                   feature))
           != 0) {
         return taggedFile;
@@ -591,19 +638,18 @@ TaggedFile* FileProxyModel::createTaggedFile(
 /**
  * Create a tagged file.
  *
- * @param dirName directory name
  * @param fileName filename
  * @param idx model index
  *
  * @return tagged file, 0 if not found or type not supported.
  */
 TaggedFile* FileProxyModel::createTaggedFile(
-    const QString& dirName, const QString& fileName,
+    const QString& fileName,
     const QPersistentModelIndex& idx) {
   TaggedFile* taggedFile = 0;
   foreach (ITaggedFileFactory* factory, s_taggedFileFactories) {
     foreach (const QString& key, factory->taggedFileKeys()) {
-      taggedFile = factory->createTaggedFile(key, dirName, fileName, idx);
+      taggedFile = factory->createTaggedFile(key, fileName, idx);
       if (taggedFile) {
         return taggedFile;
       }
@@ -623,7 +669,7 @@ TaggedFile* FileProxyModel::readWithId3V23(TaggedFile* taggedFile)
 {
   const QPersistentModelIndex& index = taggedFile->getIndex();
   if (TaggedFile* id3libFile = createTaggedFile(TaggedFile::TF_ID3v23,
-          taggedFile->getDirname(), taggedFile->getFilename(), index)) {
+          taggedFile->getFilename(), index)) {
     if (index.isValid()) {
       QVariant data;
       data.setValue(id3libFile);
@@ -664,3 +710,104 @@ TaggedFile* FileProxyModel::readWithId3V24IfId3V24(TaggedFile* taggedFile)
   }
   return taggedFile;
 }
+
+/**
+ * Read tagged file with Ogg FLAC.
+ *
+ * @param taggedFile tagged file
+ *
+ * @return tagged file (can be newly created tagged file).
+ */
+TaggedFile* FileProxyModel::readWithOggFlac(TaggedFile* taggedFile)
+{
+  const QPersistentModelIndex& index = taggedFile->getIndex();
+  if (TaggedFile* tagLibFile = createTaggedFile(TaggedFile::TF_OggFlac,
+          taggedFile->getFilename(), index)) {
+    if (index.isValid()) {
+      QVariant data;
+      data.setValue(tagLibFile);
+      // setData() will not invalidate the model, so this should be safe.
+      QAbstractItemModel* setDataModel = const_cast<QAbstractItemModel*>(
+          index.model());
+      if (setDataModel) {
+        setDataModel->setData(index, data, FileProxyModel::TaggedFileRole);
+      }
+    }
+    taggedFile = tagLibFile;
+    taggedFile->readTags(false);
+  }
+  return taggedFile;
+}
+
+/**
+ * Try to read Ogg file with invalid tag detail info as an Ogg FLAC file.
+ *
+ * @param taggedFile tagged file
+ *
+ * @return tagged file (can be new TagLibFile).
+ */
+TaggedFile* FileProxyModel::readWithOggFlacIfInvalidOgg(TaggedFile* taggedFile)
+{
+  if (taggedFile &&
+      (taggedFile->taggedFileFeatures() &
+       (TaggedFile::TF_OggPictures | TaggedFile::TF_OggFlac)) ==
+        TaggedFile::TF_OggPictures &&
+      !taggedFile->isChanged() &&
+      taggedFile->isTagInformationRead()) {
+    TaggedFile::DetailInfo info;
+    taggedFile->getDetailInfo(info);
+    if (!info.valid) {
+      taggedFile = readWithOggFlac(taggedFile);
+    }
+  }
+  return taggedFile;
+}
+
+/**
+ * Call readTags() on tagged file.
+ * Reread file with other metadata plugin if it is not supported by current
+ * plugin.
+ *
+ * @param taggedFile tagged file
+ *
+ * @return tagged file (can be new TaggedFile).
+ */
+TaggedFile* FileProxyModel::readTagsFromTaggedFile(TaggedFile* taggedFile)
+{
+  taggedFile->readTags(false);
+  taggedFile = readWithId3V24IfId3V24(taggedFile);
+  taggedFile = readWithOggFlacIfInvalidOgg(taggedFile);
+  return taggedFile;
+}
+
+/**
+ * Called from tagged file to notify modification state changes.
+ * @param index model index
+ * @param modified true if file is modified
+ */
+void FileProxyModel::notifyModificationChanged(const QModelIndex& index,
+                                               bool modified)
+{
+  emit fileModificationChanged(index, modified);
+  emit dataChanged(index, index);
+  bool lastIsModified = isModified();
+  if (modified) {
+    ++m_numModifiedFiles;
+  } else if (m_numModifiedFiles > 0) {
+    --m_numModifiedFiles;
+  }
+  bool newIsModified = isModified();
+  if (newIsModified != lastIsModified) {
+    emit modifiedChanged(newIsModified);
+  }
+}
+
+/**
+ * Called from tagged file to notify changes in extra model data, e.g. the
+ * information on which the TaggedFileIconProvider depends.
+ * @param index model index
+ */
+void FileProxyModel::notifyModelDataChanged(const QModelIndex& index)
+{
+  emit dataChanged(index, index);
+}
