@@ -40,6 +40,9 @@
 #ifdef Q_OS_MAC
 #include <QFileIconProvider>
 #endif
+#if QT_VERSION >= 0x050000 && defined Q_OS_ANDROID
+#include <QStandardPaths>
+#endif
 #ifdef HAVE_QTDBUS
 #include <QDBusConnection>
 #include <unistd.h>
@@ -114,6 +117,27 @@ QString pluginFileName(const QString& pluginName)
   return fileName;
 }
 
+/**
+ * Get text encoding from tag config as frame text encoding.
+ * @return frame text encoding.
+ */
+Frame::TextEncoding frameTextEncodingFromConfig()
+{
+  Frame::TextEncoding encoding;
+  switch (TagConfig::instance().textEncoding()) {
+  case TagConfig::TE_UTF16:
+    encoding = Frame::TE_UTF16;
+    break;
+  case TagConfig::TE_UTF8:
+    encoding = Frame::TE_UTF8;
+    break;
+  case TagConfig::TE_ISO8859_1:
+  default:
+    encoding = Frame::TE_ISO8859_1;
+  }
+  return encoding;
+}
+
 }
 
 #ifdef Q_OS_MAC
@@ -564,10 +588,20 @@ void Kid3Application::readConfig()
  */
 bool Kid3Application::openDirectory(const QStringList& paths, bool fileCheck)
 {
+  QStringList pathList(paths);
+#if QT_VERSION >= 0x050000 && defined Q_OS_ANDROID
+  if (pathList.isEmpty()) {
+    QStringList musicLocations =
+        QStandardPaths::standardLocations(QStandardPaths::MusicLocation);
+    if (!musicLocations.isEmpty()) {
+      pathList.append(musicLocations.first());
+    }
+  }
+#endif
   bool ok = true;
   QStringList filePaths;
   QStringList dirComponents;
-  foreach (const QString& path, paths) {
+  foreach (const QString& path, pathList) {
     if (!path.isEmpty()) {
       QFileInfo fileInfo(path);
       if (fileCheck && !fileInfo.exists()) {
@@ -1284,18 +1318,7 @@ void Kid3Application::applyTagFormat()
 void Kid3Application::applyTextEncoding()
 {
   emit fileSelectionUpdateRequested();
-  Frame::TextEncoding encoding;
-  switch (TagConfig::instance().textEncoding()) {
-  case TagConfig::TE_UTF16:
-    encoding = Frame::TE_UTF16;
-    break;
-  case TagConfig::TE_UTF8:
-    encoding = Frame::TE_UTF8;
-    break;
-  case TagConfig::TE_ISO8859_1:
-  default:
-    encoding = Frame::TE_ISO8859_1;
-  }
+  Frame::TextEncoding encoding = frameTextEncodingFromConfig();
   FrameCollection frames;
   SelectedTaggedFileIterator it(getRootIndex(),
                                 getFileSelectionModel(),
@@ -1858,6 +1881,7 @@ void Kid3Application::editOrAddPicture()
     editFrame();
   } else {
     PictureFrame frame;
+    PictureFrame::setTextEncoding(frame, frameTextEncodingFromConfig());
     addFrame(&frame, true);
   }
 }
@@ -1913,6 +1937,7 @@ void Kid3Application::openDrop(const QStringList& paths)
         }
         PictureFrame::setMimeTypeFromFileName(frame, fileName);
         PictureFrame::setDescription(frame, fileName);
+        PictureFrame::setTextEncoding(frame, frameTextEncodingFromConfig());
         addFrame(&frame);
         emit selectedFilesUpdated();
       }
@@ -1966,6 +1991,7 @@ void Kid3Application::dropImage(const QImage& image)
   if (!image.isNull()) {
     PictureFrame frame;
     if (PictureFrame::setDataFromImage(frame, image)) {
+      PictureFrame::setTextEncoding(frame, frameTextEncodingFromConfig());
       addFrame(&frame);
       emit selectedFilesUpdated();
     }
@@ -1995,7 +2021,8 @@ void Kid3Application::imageDownloaded(const QByteArray& data,
   // An empty mime type is accepted to allow downloads via FTP.
   if (mimeType.startsWith(QLatin1String("image")) ||
       mimeType.isEmpty()) {
-    PictureFrame frame(data, url, PictureFrame::PT_CoverFront, mimeType);
+    PictureFrame frame(data, url, PictureFrame::PT_CoverFront, mimeType,
+                       frameTextEncodingFromConfig());
     if (getDownloadImageDestination() == ImageForAllFilesInDirectory) {
       TaggedFileOfDirectoryIterator it(currentOrRootIndex());
       while (it.hasNext()) {
@@ -2887,17 +2914,30 @@ bool Kid3Application::setFrame(Frame::TagVersion tagMask,
   FrameCollection frames(ft->frames());
   FrameCollection::const_iterator it = frames.findByName(frameName);
   if (it != frames.end()) {
-    bool isPicture, isSylt;
+    QString frmName(it->getName());
+    bool isPicture, isGeob, isSylt = false;
     if (!dataFileName.isEmpty() && (tagMask & 2) != 0 &&
         ((isPicture = (it->getType() == Frame::FT_Picture)) ||
-         (isSylt = it->getName().startsWith(QLatin1String("SYLT"))) ||
-         it->getName().startsWith(QLatin1String("ETCO")))) {
+         (isGeob = frmName.startsWith(QLatin1String("GEOB"))) ||
+         (isSylt = frmName.startsWith(QLatin1String("SYLT"))) ||
+         frmName.startsWith(QLatin1String("ETCO")))) {
       if (isPicture) {
-        deleteFrame(it->getName());
+        deleteFrame(frmName);
         PictureFrame frame;
         PictureFrame::setDescription(frame, value);
         PictureFrame::setDataFromFile(frame, dataFileName);
         PictureFrame::setMimeTypeFromFileName(frame, dataFileName);
+        PictureFrame::setTextEncoding(frame, frameTextEncodingFromConfig());
+        addFrame(&frame);
+      } else if (isGeob) {
+        Frame frame(*it);
+        deleteFrame(frmName);
+        Frame::setField(frame, Frame::ID_MimeType,
+                        PictureFrame::getMimeTypeForFile(dataFileName));
+        Frame::setField(frame, Frame::ID_Filename,
+                        QFileInfo(dataFileName).fileName());
+        Frame::setField(frame, Frame::ID_Description, value);
+        PictureFrame::setDataFromFile(frame, dataFileName);
         addFrame(&frame);
       } else {
         QFile file(dataFileName);
@@ -2905,7 +2945,7 @@ bool Kid3Application::setFrame(Frame::TagVersion tagMask,
           QTextStream stream(&file);
           Frame frame(*it);
           Frame::setField(frame, Frame::ID_Description, value);
-          deleteFrame(it->getName());
+          deleteFrame(frmName);
           TimeEventModel timeEventModel;
           if (isSylt) {
             timeEventModel.setType(TimeEventModel::SynchronizedLyrics);
@@ -2921,7 +2961,7 @@ bool Kid3Application::setFrame(Frame::TagVersion tagMask,
         }
       }
     } else if (value.isEmpty() && (tagMask & 2) != 0) {
-      deleteFrame(it->getName());
+      deleteFrame(frmName);
     } else {
       Frame& frame = const_cast<Frame&>(*it);
       frame.setValueIfChanged(value);
@@ -2933,16 +2973,25 @@ bool Kid3Application::setFrame(Frame::TagVersion tagMask,
     return true;
   } else if (tagMask & 2) {
     Frame frame(Frame::ExtendedType(frameName), value, -1);
-    bool isPicture, isSylt;
+    QString frmName(frame.getInternalName());
+    bool isPicture, isGeob, isSylt = false;
     if (!dataFileName.isEmpty() &&
         ((isPicture = (frame.getType() == Frame::FT_Picture)) ||
-         (isSylt = frame.getInternalName().startsWith(QLatin1String("SYLT"))) ||
-         frame.getInternalName().startsWith(QLatin1String("ETCO")))) {
+         (isGeob = frmName.startsWith(QLatin1String("GEOB"))) ||
+         (isSylt = frmName.startsWith(QLatin1String("SYLT"))) ||
+         frmName.startsWith(QLatin1String("ETCO")))) {
       if (isPicture) {
         PictureFrame::setFields(frame);
         PictureFrame::setDescription(frame, value);
         PictureFrame::setDataFromFile(frame, dataFileName);
         PictureFrame::setMimeTypeFromFileName(frame, dataFileName);
+        PictureFrame::setTextEncoding(frame, frameTextEncodingFromConfig());
+      } else if (isGeob) {
+        PictureFrame::setGeobFields(
+              frame, Frame::TE_ISO8859_1,
+              PictureFrame::getMimeTypeForFile(dataFileName),
+              QFileInfo(dataFileName).fileName(), value);
+        PictureFrame::setDataFromFile(frame, dataFileName);
       } else {
         QFile file(dataFileName);
         if (file.open(QIODevice::ReadOnly)) {
@@ -3008,6 +3057,7 @@ void Kid3Application::setPictureData(const QByteArray& data)
   }
   if (!data.isEmpty()) {
     PictureFrame::setData(frame, data);
+    PictureFrame::setTextEncoding(frame, frameTextEncodingFromConfig());
     addFrame(&frame);
   }
 }
