@@ -29,6 +29,7 @@
 
 #include <QObject>
 #include <QPersistentModelIndex>
+#include <QUrl>
 #include "frame.h"
 #include "trackdata.h"
 #include "filefilter.h"
@@ -36,15 +37,19 @@
 #include "generalconfig.h"
 #include "config.h"
 
+class QFileIconProvider;
 class QFileSystemModel;
 class QItemSelectionModel;
 class QModelIndex;
 class QNetworkAccessManager;
+class QDir;
 class FileProxyModel;
 class FileProxyModelIterator;
 class DirProxyModel;
 class TrackDataModel;
+class GenreModel;
 class FrameTableModel;
+class TaggedFileSelection;
 class ConfigStore;
 class PlaylistConfig;
 class DownloadClient;
@@ -60,15 +65,65 @@ class BatchImportProfile;
 class BatchImporter;
 class IAbortable;
 class ICorePlatformTools;
+class IUserCommandProcessor;
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
 class AudioPlayer;
 #endif
+class PixmapProvider;
+class FrameEditorObject;
 
 /**
  * Kid3 application logic, independent of GUI.
  */
 class KID3_CORE_EXPORT Kid3Application : public QObject {
   Q_OBJECT
+  /** File proxy model. */
+  Q_PROPERTY(FileProxyModel* fileProxyModel READ getFileProxyModel CONSTANT)
+  /** Directory proxy model. */
+  Q_PROPERTY(DirProxyModel* dirProxyModel READ getDirProxyModel CONSTANT)
+  /** File selection model. */
+  Q_PROPERTY(QItemSelectionModel* fileSelectionModel READ getFileSelectionModel CONSTANT)
+  /** Directory selection model. */
+  Q_PROPERTY(QItemSelectionModel* dirSelectionModel READ getDirSelectionModel CONSTANT)
+  /** Tag 1 genre model. */
+  Q_PROPERTY(GenreModel* genreModelV1 READ genreModelV1 CONSTANT)
+  /** Tag 2 genre model. */
+  Q_PROPERTY(GenreModel* genreModelV2 READ genreModelV2 CONSTANT)
+  /** Tag 1 frame table model. */
+  Q_PROPERTY(FrameTableModel* frameModelV1 READ frameModelV1 CONSTANT)
+  /** Tag 2 frame table model. */
+  Q_PROPERTY(FrameTableModel* frameModelV2 READ frameModelV2 CONSTANT)
+  /** Tag 1 frame selection model. */
+  Q_PROPERTY(QItemSelectionModel* frameSelectionModelV1 READ getFramesV1SelectionModel CONSTANT)
+  /** Tag 1 frame selection model. */
+  Q_PROPERTY(QItemSelectionModel* frameSelectionModelV2 READ getFramesV2SelectionModel CONSTANT)
+  /** Frame list. */
+  Q_PROPERTY(FrameList* frameList READ getFrameList CONSTANT)
+  /** Information about selected tagged files. */
+  Q_PROPERTY(TaggedFileSelection* selectionInfo READ selectionInfo CONSTANT)
+  /** Root index of opened directory in file proxy model. */
+  Q_PROPERTY(QModelIndex fileRootIndex READ getRootIndex NOTIFY fileRootIndexChanged)
+  /** Root index of opened directory in directory proxy model. */
+  Q_PROPERTY(QModelIndex dirRootIndex READ getDirRootIndex NOTIFY dirRootIndexChanged)
+  /** Directory name. */
+  Q_PROPERTY(QString dirName READ getDirName NOTIFY dirNameChanged)
+  /** Modification state. */
+  Q_PROPERTY(bool modified READ isModified NOTIFY modifiedChanged)
+  /** Filtered state. */
+  Q_PROPERTY(bool filtered READ isFiltered WRITE setFiltered NOTIFY filteredChanged)
+  /** Frame editor. */
+  Q_PROPERTY(FrameEditorObject* frameEditor READ frameEditor WRITE setFrameEditor
+             NOTIFY frameEditorChanged)
+  /** ID to get cover art image. */
+  Q_PROPERTY(QString coverArtImageId READ coverArtImageId
+             NOTIFY coverArtImageIdChanged)
+  /** Directory renamer. */
+  Q_PROPERTY(DirRenamer* dirRenamer READ getDirRenamer CONSTANT)
+  /** Batch importer. */
+  Q_PROPERTY(BatchImporter* batchImporter READ getBatchImporter CONSTANT)
+  /** Download client */
+  Q_PROPERTY(DownloadClient* downloadClient READ getDownloadClient CONSTANT)
+  Q_FLAGS(NumberTrackOption NumberTrackOptions)
 public:
   /** Destination for downloadImage(). */
   enum DownloadImageDestination {
@@ -77,6 +132,13 @@ public:
     ImageForImportTrackData      /**< for enabled files in m_trackDataModel */
   };
 
+  /** Options for numberTracks(). */
+  enum NumberTrackOption {
+    NumberTracksEnabled = 1,                     /**< Enable track numbering */
+    NumberTracksResetCounterForEachDirectory = 2 /**< Reset counter */
+  };
+  Q_DECLARE_FLAGS(NumberTrackOptions, NumberTrackOption)
+
   /**
    * Constructor.
    * @param platformTools platform tools
@@ -127,6 +189,33 @@ public:
    */
   QItemSelectionModel* getFileSelectionModel() { return m_fileSelectionModel; }
 
+  /**
+   * Get selection model of directories.
+   */
+  QItemSelectionModel* getDirSelectionModel() { return m_dirSelectionModel; }
+
+  /**
+   * Store index of directory from where "directory up" (..) is activated.
+   * This directory will then be selected in the new (parent) directory.
+   *
+   * @param index model index of target directory entered when going up
+   */
+  void setDirUpIndex(const QPersistentModelIndex& index) {
+    m_dirUpIndex = index;
+  }
+
+  /**
+   * Get tag 1 genre model.
+   * @return genre model.
+   */
+  GenreModel*  genreModelV1() const { return m_genreModelV1; }
+
+  /**
+   * Get tag 2 genre model.
+   * @return genre model.
+   */
+  GenreModel*  genreModelV2() const { return m_genreModelV2; }
+
   /**
    * Get tag 1 frame table model.
    * @return frame table.
@@ -191,6 +280,14 @@ public:
     return m_trackImporters;
   }
 
+  /**
+   * Get available user command processors.
+   * @return list of user command processors.
+   */
+  QList<IUserCommandProcessor*> getUserCommandProcessors() {
+    return m_userCommandProcessors;
+  }
+
   /**
    * Get tag searcher.
    * @return tag searcher.
@@ -214,7 +311,7 @@ public:
    * Get audio player.
    * @return audio player.
    */
-  AudioPlayer* getAudioPlayer();
+  Q_INVOKABLE AudioPlayer* getAudioPlayer();
 #endif
 
   /**
@@ -224,15 +321,20 @@ public:
    */
   QModelIndex currentOrRootIndex() const;
 
+  /**
+   * Apply configuration changes.
+   */
+  Q_INVOKABLE void applyChangedConfiguration();
+
   /**
    * Save settings to the configuration.
    */
-  void saveConfig();
+  Q_INVOKABLE void saveConfig();
 
   /**
    * Read settings from the configuration.
    */
-  void readConfig();
+  Q_INVOKABLE void readConfig();
 
   /**
    * Open directory.
@@ -244,7 +346,7 @@ public:
    *
    * @return true if ok.
    */
-  bool openDirectory(const QStringList& paths, bool fileCheck = false);
+  Q_INVOKABLE bool openDirectory(const QStringList& paths, bool fileCheck = false);
 
   /**
    * Get root index of opened directory in file proxy model.
@@ -254,6 +356,12 @@ public:
     return m_fileProxyModelRootIndex;
   }
 
+  /**
+   * Get root index of opened directory in directory proxy model.
+   * @return index of directory root.
+   */
+  QModelIndex getDirRootIndex() const { return m_dirProxyModelRootIndex; }
+
   /**
    * Get directory path of opened directory.
    * @return directory path.
@@ -266,58 +374,24 @@ public:
    *
    * @return list of files with error, empty if ok.
    */
-  QStringList saveDirectory();
+  Q_INVOKABLE QStringList saveDirectory();
 
   /**
    * Update tags of selected files to contain contents of frame models.
-   *
-   * @param selItems list of selected file indexes
    */
-  void frameModelsToTags(const QList<QPersistentModelIndex>& selItems);
+  Q_INVOKABLE void frameModelsToTags();
 
   /**
    * Update frame models to contain contents of selected files.
    * The properties starting with "selection" will be set by this method.
-   *
-   * @param selItems list of selected file indexes
    */
-  void tagsToFrameModels(const QList<QPersistentModelIndex>& selItems);
+  Q_INVOKABLE void tagsToFrameModels();
 
   /**
-   * Check if a single file is selected.
-   * @return if a single file is selected, this tagged file, else 0.
+   * Access to information about selected tagged files.
+   * @return selection information.
    */
-  const TaggedFile* selectionSingleFile() const {
-    return m_selectionSingleFile;
-  }
-
-  /**
-   * Number of selected files which support tag 1.
-   * @return number of selected files which support tag 1.
-   */
-  int selectionTagV1SupportedCount() const {
-    return m_selectionTagV1SupportedCount;
-  }
-
-  /**
-   * Number of selected files.
-   * @return number of selected files which support tag 2.
-   */
-  int selectionFileCount() const {
-    return m_selectionFileCount;
-  }
-
-  /**
-   * Check if any of the selected files has a tag 1.
-   * @return true if any of the selected files has a tag 1.
-   */
-  bool selectionHasTagV1() const { return m_selectionHasTagV1; }
-
-  /**
-   * Check if any of the selected files has a tag 2.
-   * @return true if any of the selected files has a tag 2.
-   */
-  bool selectionHasTagV2() const { return m_selectionHasTagV2; }
+  TaggedFileSelection* selectionInfo() const { return m_selection; }
 
   /**
    * Import.
@@ -328,8 +402,8 @@ public:
    *
    * @return true if ok.
    */
-  bool importTags(TrackData::TagVersion tagMask, const QString& path,
-                  int fmtIdx);
+  Q_INVOKABLE bool importTags(Frame::TagVersion tagMask, const QString& path,
+                              int fmtIdx);
 
   /**
    * Export.
@@ -340,8 +414,8 @@ public:
    *
    * @return true if ok.
    */
-  bool exportTags(TrackData::TagVersion tagVersion,
-                  const QString& path, int fmtIdx);
+  Q_INVOKABLE bool exportTags(Frame::TagVersion tagVersion,
+                              const QString& path, int fmtIdx);
 
   /**
    * Write playlist according to playlist configuration.
@@ -357,7 +431,7 @@ public:
    *
    * @return true if ok.
    */
-  bool writePlaylist();
+  Q_INVOKABLE bool writePlaylist();
 
   /**
    * Perform rename actions and change application directory afterwards if it
@@ -365,7 +439,7 @@ public:
    *
    * @return error messages, null string if no error occurred.
    */
-  QString performRenameActions();
+  Q_INVOKABLE QString performRenameActions();
 
   /**
    * Set the directory name from the tags.
@@ -380,7 +454,7 @@ public:
    *
    * @return true if ok.
    */
-  bool renameDirectory(TrackData::TagVersion tagMask,
+  Q_INVOKABLE bool renameDirectory(Frame::TagVersion tagMask,
                        const QString& format, bool create);
 
   /**
@@ -389,8 +463,10 @@ public:
    * @param nr start number
    * @param total total number of tracks, used if >0
    * @param tagVersion determines on which tags the numbers are set
+   * @param options options for numbering operation
    */
-  void numberTracks(int nr, int total, TrackData::TagVersion tagVersion);
+  Q_INVOKABLE void numberTracks(int nr, int total, Frame::TagVersion tagVersion,
+                                NumberTrackOptions options = 0);
 
   /**
    * Set track data with tagged files of directory.
@@ -398,7 +474,7 @@ public:
    * @param tagVersion tag version
    * @param trackDataList is filled with track data
    */
-  void filesToTrackData(TrackData::TagVersion tagVersion,
+  void filesToTrackData(Frame::TagVersion tagVersion,
                         ImportTrackDataVector& trackDataList);
 
   /**
@@ -406,14 +482,14 @@ public:
    *
    * @param tagVersion tag version
    */
-  void filesToTrackDataModel(TrackData::TagVersion tagVersion);
+  void filesToTrackDataModel(Frame::TagVersion tagVersion);
 
   /**
    * Set tagged files of directory from track data model.
    *
    * @param tagVersion tags to set
    */
-  void trackDataModelToFiles(TrackData::TagVersion tagVersion);
+  void trackDataModelToFiles(Frame::TagVersion tagVersion);
 
   /**
    * Download an image file.
@@ -421,7 +497,15 @@ public:
    * @param url  URL of image
    * @param dest specifies affected files
    */
-  void downloadImage(const QString& url, DownloadImageDestination dest);
+  void downloadImage(const QUrl& url, DownloadImageDestination dest);
+
+  /**
+   * Download an image file.
+   *
+   * @param url URL of image
+   * @param allFilesInDir true to add the image to all files in the directory
+   */
+  Q_INVOKABLE void downloadImage(const QString& url, bool allFilesInDir);
 
   /**
    * Get value of frame.
@@ -430,8 +514,20 @@ public:
    *
    * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
    * @param name    name of frame (e.g. "artist")
+   *
+   * @return value of frame.
    */
-  QString getFrame(TrackData::TagVersion tagMask, const QString& name);
+  Q_INVOKABLE QString getFrame(Frame::TagVersion tagMask,
+                               const QString& name) const;
+
+  /**
+   * Get names and values of all frames.
+   *
+   * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
+   *
+   * @return map containing frame values.
+   */
+  Q_INVOKABLE QVariantMap getAllFrames(Frame::TagVersion tagMask) const;
 
   /**
    * Set value of frame.
@@ -444,8 +540,20 @@ public:
    * @param name    name of frame (e.g. "artist")
    * @param value   value of frame
    */
-  bool setFrame(TrackData::TagVersion tagMask, const QString& name,
-                const QString& value);
+  Q_INVOKABLE bool setFrame(Frame::TagVersion tagMask, const QString& name,
+                            const QString& value);
+
+  /**
+   * Get data from picture frame.
+   * @return picture data, empty if not found.
+   */
+  Q_INVOKABLE QByteArray getPictureData() const;
+
+  /**
+   * Set data in picture frame.
+   * @param data picture data
+   */
+  Q_INVOKABLE void setPictureData(const QByteArray& data);
 
   /**
    * Format a filename if format while editing is switched on.
@@ -471,16 +579,16 @@ public:
   /**
    * Handle URL on drop.
    *
-   * @param txt dropped URL.
+   * @param url dropped URL.
    */
-  void dropUrl(const QString& txt);
+  void dropUrl(const QUrl& url);
 
   /**
    * Get number of tracks in current directory.
    *
    * @return number of tracks, 0 if not found.
    */
-  int getTotalNumberOfTracksInDir();
+  Q_INVOKABLE int getTotalNumberOfTracksInDir();
 
   /**
    * Get name of selected file.
@@ -495,7 +603,7 @@ public:
    *
    * @return filter string.
    */
-  QString createFilterString() const;
+  Q_INVOKABLE QString createFilterString() const;
 
   /**
    * Get image destination set by downloadImage().
@@ -505,54 +613,26 @@ public:
     return m_downloadImageDest;
   }
 
-  /**
-   * Set modification state.
-   *
-   * @param val true if a file is modified
-   */
-  void setModified(bool val) { m_modified = val; }
-
   /**
    * Check modification state.
    *
    * @return true if a file is modified.
    */
-  bool isModified() { return m_modified; }
-
-  /**
-   * Update modification state from files.
-   */
-  void updateModified();
+  bool isModified() const;
 
   /**
    * Set filter state.
    *
    * @param val true if list is filtered
    */
-  void setFiltered(bool val) { m_filtered = val; }
+  void setFiltered(bool val);
 
   /**
    * Check filter state.
    *
    * @return true if list is filtered.
    */
-  bool isFiltered() { return m_filtered; }
-
-  /**
-   * Get format used to generate filename from tags.
-   * @return format
-   */
-  QString getFilenameToTagsFormat() const {
-    return m_filenameToTagsFormat;
-  }
-
-  /**
-   * Get format used to generate tags from filename.
-   * @return format
-   */
-  QString getTagsToFilenameFormat() const {
-    return m_tagsToFilenameFormat;
-  }
+  bool isFiltered() const { return m_filtered; }
 
   /**
    * Get the selected file.
@@ -562,23 +642,94 @@ public:
    */
   TaggedFile* getSelectedFile();
 
+  /**
+   * Get the stored current selection.
+   * @return stored selection.
+   */
+  const QList<QPersistentModelIndex>& getCurrentSelection() const {
+    return m_currentSelection;
+  }
+
+  /**
+   * Update the stored current selection with the list of all selected items.
+   */
+  void updateCurrentSelection();
+
   /**
    * Get directory name.
    * @return directory.
    */
-  static QString getDirName() { return s_dirName; }
+  QString getDirName() const { return m_dirName; }
 
   /**
-   * Set directory name.
-   * @param dirName directory.
+   * Get frame editor set with setFrameEditor().
+   * @return frame editor, null if no frame editor is set
    */
-  static void setDirName(const QString& dirName) { s_dirName = dirName; }
+  FrameEditorObject* frameEditor() const { return m_frameEditor; }
+
+  /**
+   * Set a frame editor object to act as the frame editor.
+   * @param frameEditor frame editor object, null to disable
+   */
+  void setFrameEditor(FrameEditorObject* frameEditor);
+
+  /**
+   * Remove frame editor.
+   * Has to be called in the destructor of the frame editor to avoid a dangling
+   * pointer to a deleted object.
+   * @param frameEditor frame editor
+   */
+  void removeFrameEditor(IFrameEditor* frameEditor);
+
+  /**
+   * Get ID to get cover art image.
+   * @return ID for cover art image.
+   */
+  QString coverArtImageId() const { return m_coverArtImageId; }
+
+  /**
+   * Set the image provider.
+   * @param imageProvider image provider
+   */
+  void setImageProvider(PixmapProvider* imageProvider);
+
+  /**
+   * Get the numbers of the selected rows in a list suitable for scripting.
+   * @return list with row numbers.
+   */
+  Q_INVOKABLE QVariantList getFileSelectionRows();
+
+  /**
+   * Set the file selection from a list of model indexes.
+   * @param indexes list of model indexes suitable for scripting
+   */
+  Q_INVOKABLE void setFileSelectionIndexes(const QVariantList& indexes);
+
+  /**
+   * Set picture data for image provider.
+   * @param picture picture data
+   */
+  Q_INVOKABLE void setCoverArtImageData(const QByteArray& picture);
 
   /**
    * Notify the tagged file factories about the changed configuration.
    */
   static void notifyConfigurationChange();
 
+  /**
+   * Find directory containing plugins.
+   * @param pluginsDir the plugin directory is returned here
+   * @return true if found.
+   */
+  static bool findPluginsDirectory(QDir& pluginsDir);
+
+  /**
+   * Set fallback path for directory containing plugins.
+   * @param path path to be searched for plugins if they are not found at the
+   * standard location relative to the application directory
+   */
+  static void setPluginsPathFallback(const QString& path);
+
   /**
    * Load plugins.
    * @return list of plugin instances.
@@ -593,6 +744,13 @@ public slots:
    */
   void openDrop(const QStringList& paths);
 
+  /**
+   * Handle drop of URLs.
+   *
+   * @param urlList picture, tagged file and folder URLs to handle (if local)
+   */
+  void openDropUrls(const QList<QUrl>& urlList);
+
   /**
    * Revert file modifications.
    * Acts on selected files or all files if no file is selected.
@@ -613,9 +771,9 @@ public slots:
   void applyFilenameFormat();
 
   /**
-   * Apply ID3 format.
+   * Apply tag format.
    */
-  void applyId3Format();
+  void applyTagFormat();
 
   /**
    * Apply text encoding.
@@ -649,7 +807,7 @@ public slots:
    *
    * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
    */
-  void copyTags(TrackData::TagVersion tagMask);
+  void copyTags(Frame::TagVersion tagMask);
 
   /**
    * Paste from copy buffer to ID3v1 tags.
@@ -666,7 +824,7 @@ public slots:
    *
    * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
    */
-  void pasteTags(TrackData::TagVersion tagMask);
+  void pasteTags(Frame::TagVersion tagMask);
 
   /**
    * Copy ID3v1 tags to ID3v2 tags of selected files.
@@ -683,7 +841,7 @@ public slots:
    *
    * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
    */
-  void copyToOtherTag(TrackData::TagVersion tagMask);
+  void copyToOtherTag(Frame::TagVersion tagMask);
 
   /**
    * Remove ID3v1 tags in selected files.
@@ -700,7 +858,7 @@ public slots:
    *
    * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
    */
-  void removeTags(TrackData::TagVersion tagMask);
+  void removeTags(Frame::TagVersion tagMask);
 
   /**
    * Set ID3v1 tags according to filename.
@@ -721,37 +879,7 @@ public slots:
    *
    * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
    */
-  void getTagsFromFilename(TrackData::TagVersion tagMask);
-
-  /**
-   * Set format used to generate filename from tags.
-   * @param format format
-   */
-  void setFilenameToTagsFormat(const QString& format);
-
-  /**
-   * Set format used to generate filename from tags without emitting
-   * filenameToTagsFormatChanged() signal.
-   * This has to be used when connected from the GUI to avoid that the GUI
-   * is updated because of its own changes.
-   * @param format format
-   */
-  void setFilenameToTagsFormatWithoutSignaling(const QString& format);
-
-  /**
-   * Set format used to generate tags from filename.
-   * @param format format
-   */
-  void setTagsToFilenameFormat(const QString& format);
-
-  /**
-   * Set format used to generate tags from filename without emitting
-   * tagsToFilenameFormatChanged() signal.
-   * This has to be used when connected from the GUI to avoid that the GUI
-   * is updated because of its own changes.
-   * @param format format
-   */
-  void setTagsToFilenameFormatWithoutSignaling(const QString& format);
+  void getTagsFromFilename(Frame::TagVersion tagMask);
 
   /**
    * Set filename according to tags.
@@ -760,14 +888,12 @@ public slots:
    *
    * @param tagVersion tag version
    */
-  void getFilenameFromTags(TrackData::TagVersion tagVersion);
+  void getFilenameFromTags(Frame::TagVersion tagVersion);
 
   /**
    * Edit selected frame.
-   *
-   * @param frameEditor editor for frame fields
    */
-  void editFrame(IFrameEditor* frameEditor);
+  void editFrame();
 
   /**
    * Delete selected frame.
@@ -777,20 +903,14 @@ public slots:
   void deleteFrame(const QString& frameName = QString());
 
   /**
-   * Select a frame type and add such a frame to frame list.
-   *
-   * @param frame frame to add, if 0 the user has to select and edit the frame
-   * @param frameEditor editor for frame fields, if not null and a frame
-   * is set, the user can edit the frame before it is added
+   * Select a frame type and add such a frame to the frame list.
    */
-  void addFrame(const Frame* frame, IFrameEditor* frameEditor = 0);
+  void selectAndAddFrame();
 
   /**
    * Edit a picture frame if one exists or add a new one.
-   *
-   * @param frameEditor editor for frame fields
    */
-  void editOrAddPicture(IFrameEditor* frameEditor);
+  void editOrAddPicture();
 
   /**
    * Add a downloaded image.
@@ -848,6 +968,11 @@ public slots:
    */
   void deselectAllFiles();
 
+  /**
+   * Select all files in the current directory.
+   */
+  void selectAllInDirectory();
+
   /**
    * Fetch entries of directory if not already fetched.
    * This works like FileList::expand(), but without expanding tree view
@@ -870,6 +995,11 @@ public slots:
    */
   void requestExpandFileList();
 
+  /**
+   * Called when operation for requestExpandFileList() is finished.
+   */
+  void notifyExpandFileListFinished();
+
   /**
    * Process change of selection.
    * The GUI is signaled to update the current selection and the controls.
@@ -925,7 +1055,15 @@ public slots:
    * @param tagVersion import destination tag versions
    */
   void batchImport(const BatchImportProfile& profile,
-                   TrackData::TagVersion tagVersion);
+                   Frame::TagVersion tagVersion);
+
+  /**
+   * Perform a batch import for the selected directories.
+   * @param profileName batch import profile name
+   * @param tagVersion import destination tag versions
+   * @return true if profile with @a profileName found.
+   */
+  bool batchImport(const QString& profileName, Frame::TagVersion tagVersion);
 
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
@@ -939,14 +1077,30 @@ public slots:
   void showAudioPlayer();
 #endif
 
+  /**
+   * Close the file handle of a tagged file.
+   * @param filePath path to file
+   */
+  void closeFileHandle(const QString& filePath);
+
 signals:
   /**
-   * Emitted when a new directory is opened.
-   * @param directoryIndex root path file proxy model index
-   * @param fileIndexes file path indexes in the file proxy model
+   * Emitted when the file proxy model root index changes.
+   * @param index new root index
    */
-  void directoryOpened(const QPersistentModelIndex& directoryIndex,
-                       const QList<QPersistentModelIndex>& fileIndexes);
+  void fileRootIndexChanged(const QModelIndex& index);
+
+  /**
+   * Emitted when the directory proxy model root index changes.
+   * @param index new root index
+   */
+  void dirRootIndexChanged(const QModelIndex& index);
+
+  /**
+   * Emitted when the directory has been opened, the file and directory proxy
+   * model root indexes changed and the selection updated.
+   */
+  void directoryOpened();
 
   /**
    * Emitted when a confirmed opening of a directory or file is requested.
@@ -990,30 +1144,31 @@ signals:
   void frameModified(TaggedFile* taggedFile);
 
   /**
-   * Emitted after a file has been modified.
-   * The GUI should update its modification state when receiving this signal.
+   * Emitted when modification state is changed.
+   * @param modified true if any file is modified
+   * @see isModified()
    */
-  void fileModified();
+  void modifiedChanged(bool modified);
 
   /**
-   * Emitted when setFilenameToTagsFormat() changed.
-   * @param format new format
+   * Emitted when filtered state is changed.
+   * @param filtered true if file list is filtered
+   * @see isFiltered(), setFiltered()
    */
-  void filenameToTagsFormatChanged(const QString& format);
+  void filteredChanged(bool filtered);
 
   /**
-   * Emitted when setTagsToFilenameFormat() changed.
-   * @param format new format
+   * Emitted when the directory name is changed.
+   * @param name current directory name
    */
-  void tagsToFilenameFormatChanged(const QString& format);
+  void dirNameChanged(const QString& name);
 
   /**
    * Emitted when a file is filtered.
-   * @param type filter event type
+   * @param type filter event type, enum FileFilter::FilterEventType
    * @param fileName name of filtered file
    */
-  void fileFiltered(FileFilter::FilterEventType type,
-                    const QString& fileName);
+  void fileFiltered(int type, const QString& fileName);
 
   /**
    * Emitted before an audio file is played.
@@ -1039,6 +1194,29 @@ signals:
    */
   void expandFileListRequested();
 
+  /**
+   * Emitted when operation requested by requestExpandFileList()
+   * (signal expandFileListRequested()) is finished.
+   */
+  void expandFileListFinished();
+
+  /**
+   * Emitted when the file selection is changed.
+   * @see getFileSelectionRows()
+   */
+  void fileSelectionChanged();
+
+  /**
+   * Emitted when a new cover art image is available
+   * @param id ID of image.
+   */
+  void coverArtImageIdChanged(const QString& id);
+
+  /**
+   * Emitted when the frame editor is changed.
+   */
+  void frameEditorChanged();
+
 private slots:
   /**
    * Apply single file to file filter.
@@ -1062,9 +1240,9 @@ private slots:
   void scheduleNextRenameAction(const QPersistentModelIndex& index);
 
   /**
-   * Emit directoryOpened().
+   * Update selection and emit signals when directory is opened.
    */
-  void emitDirectoryOpened();
+  void onDirectoryOpened();
 
   /**
    * Called when the gatherer thread has finished to load the directory.
@@ -1083,6 +1261,13 @@ private slots:
    */
   void onFrameAdded(const Frame* frame);
 
+  /**
+   * If an image provider is used, update its picture and change the
+   * coverArtImageId property if the picture of the selection changed.
+   * This can be used to change a QML image.
+   */
+  void updateCoverArtImageId();
+
 private:
   /**
    * Load and initialize plugins depending on configuration.
@@ -1095,23 +1280,45 @@ private:
    */
   void checkPlugin(QObject* plugin);
 
+  /**
+   * Select a frame type and add such a frame to frame list.
+   *
+   * @param frame frame to add, if 0 the user has to select and edit the frame
+   * @param edit if true and a frame is set, the user can edit the frame before
+   * it is added
+   */
+  void addFrame(const Frame* frame, bool edit = false);
+
+  /**
+   * Set the coverArtImageId property to a new value.
+   * This can be used to trigger an update of QML images.
+   */
+  void setNextCoverArtImageId();
+
   ICorePlatformTools* m_platformTools;
+  /** Configuration */
+  ConfigStore* m_configStore;
   /** model of filesystem */
+#ifdef Q_OS_MAC
+  QFileIconProvider* m_defaultFileIconProvider;
+  QFileIconProvider* m_fileIconProvider;
+#endif
   QFileSystemModel* m_fileSystemModel;
   FileProxyModel* m_fileProxyModel;
   FileProxyModelIterator* m_fileProxyModelIterator;
   DirProxyModel* m_dirProxyModel;
   QItemSelectionModel* m_fileSelectionModel;
+  QItemSelectionModel* m_dirSelectionModel;
   /** Track data model */
   TrackDataModel* m_trackDataModel;
+  GenreModel* m_genreModelV1;
+  GenreModel* m_genreModelV2;
   FrameTableModel* m_framesV1Model;
   FrameTableModel* m_framesV2Model;
   QItemSelectionModel* m_framesV1SelectionModel;
   QItemSelectionModel* m_framesV2SelectionModel;
   /** Frame list */
   FrameList* m_framelist;
-  /** Configuration */
-  ConfigStore* m_configStore;
   /** Network access manager */
   QNetworkAccessManager* m_netMgr;
   /** Download client */
@@ -1129,37 +1336,38 @@ private:
   AudioPlayer* m_player;
 #endif
   FileFilter* m_expressionFileFilter;
+  /** Information about selected tagged files */
+  TaggedFileSelection* m_selection;
   /** Affected files to add frame when downloading image */
   DownloadImageDestination m_downloadImageDest;
   /** Copy buffer */
   FrameCollection m_copyTags;
   /** Root index in file proxy model */
   QPersistentModelIndex m_fileProxyModelRootIndex;
+  /** Root index in directory proxy model */
+  QModelIndex m_dirProxyModelRootIndex;
   /** Indexes of opened file in file proxy model */
   QList<QPersistentModelIndex> m_fileProxyModelFileIndexes;
-  /** Format to generate tags from filename */
-  QString m_filenameToTagsFormat;
-  /** Format to generate filename from tags */
-  QString m_tagsToFilenameFormat;
   /** Importers for different servers */
   QList<ServerImporter*> m_importers;
   /** Importer for MusicBrainz fingerprints */
   QList<ServerTrackImporter*> m_trackImporters;
-
-  /* Context for updateFrameModels() */
-  /** If a single file is selected, this tagged file, else 0 */
-  TaggedFile* m_selectionSingleFile;
-  /** Number of selected files which support tag 1 */
-  int m_selectionTagV1SupportedCount;
-  /** Number of selected files */
-  int m_selectionFileCount;
+  /** Processors for user commands */
+  QList<IUserCommandProcessor*> m_userCommandProcessors;
+  /** Current directory */
+  QString m_dirName;
+  /** Stored current selection with the list of all selected items */
+  QList<QPersistentModelIndex> m_currentSelection;
+  /** directory from where "directory up" (..) was activated. */
+  QPersistentModelIndex m_dirUpIndex;
 
   /* Context for filterNextFile() */
   FileFilter* m_fileFilter;
   QString m_lastProcessedDirName;
   /* Context for batchImportNextFile() */
+  BatchImportProfile* m_namedBatchImportProfile;
   const BatchImportProfile* m_batchImportProfile;
-  TrackData::TagVersion m_batchImportTagVersion;
+  Frame::TagVersion m_batchImportTagVersion;
   QList<ImportTrackDataVector> m_batchImportAlbums;
   ImportTrackDataVector m_batchImportTrackDataList;
 
@@ -1170,17 +1378,18 @@ private:
   /* Context for addFrame() */
   TaggedFile* m_addFrameTaggedFile;
 
-  /** true if any file was modified */
-  bool m_modified;
+  /* Support for frame editor object */
+  FrameEditorObject* m_frameEditor;
+  IFrameEditor* m_storedFrameEditor;
+  /* Support for image provider */
+  PixmapProvider* m_imageProvider;
+  QString m_coverArtImageId;
+
   /** true if list is filtered */
   bool m_filtered;
-  /** true if any of the selected files has a tag 1 */
-  bool m_selectionHasTagV1;
-  /** true if any of the selected files has a tag 2 */
-  bool m_selectionHasTagV2;
 
-  /** Current directory */
-  static QString s_dirName;
+  /** Fallback for path to search for plugins */
+  static QString s_pluginsPathFallback;
 };
 
 #endif // KID3APPLICATION_H
