@@ -40,6 +40,7 @@
 #include "modeliterator.h"
 #include "batchimportconfig.h"
 #include "batchimportprofile.h"
+#include "fileconfig.h"
 
 /**
  * Constructor.
@@ -133,12 +134,7 @@ bool ScriptInterface::importFromFile(int tagMask, const QString& path,
  */
 bool ScriptInterface::batchImport(int tagMask, const QString& profileName)
 {
-  BatchImportProfile profile;
-  if (BatchImportConfig::instance().getProfileByName(profileName, profile)) {
-    m_app->batchImport(profile, TrackData::tagVersionCast(tagMask));
-    return true;
-  }
-  return false;
+  return m_app->batchImport(profileName, TrackData::tagVersionCast(tagMask));
 }
 
 /**
@@ -149,9 +145,7 @@ bool ScriptInterface::batchImport(int tagMask, const QString& profileName)
  */
 void ScriptInterface::downloadAlbumArt(const QString& url, bool allFilesInDir)
 {
-  m_app->downloadImage(url, allFilesInDir
-    ? Kid3Application::ImageForAllFilesInDirectory
-    : Kid3Application::ImageForSelectedFiles);
+  m_app->downloadImage(url, allFilesInDir);;
 }
 
 /**
@@ -314,7 +308,7 @@ void ScriptInterface::applyFilenameFormat()
  */
 void ScriptInterface::applyTagFormat()
 {
-  m_app->applyId3Format();
+  m_app->applyTagFormat();
 }
 
 /**
@@ -436,7 +430,7 @@ void ScriptInterface::setFileName(const QString& name)
  */
 void ScriptInterface::setFileNameFormat(const QString& format)
 {
-  m_app->setTagsToFilenameFormat(format);
+  FileConfig::instance().setToFilenameFormat(format);
 }
 
 /**
