@@ -133,7 +133,10 @@ public:
     ID_Seller,
 
     // Additional field for METADATA_BLOCK_PICTURE
-    ID_ImageProperties
+    ID_ImageProperties,
+
+    // Type of subframe in CTOC and CHAP frames
+    ID_Subframe
   };
 
   /** Text encoding for fields of type ID_TextEnc. */
@@ -605,13 +608,13 @@ public:
   static QVariant getField(const Frame& frame, FieldId id);
 
   /**
-   * Get type of frame from translated name.
+   * Get type of frame from English name.
    *
-   * @param translatedName name, spaces and case are ignored
+   * @param name name, spaces and case are ignored
    *
    * @return type.
    */
-  static Type getTypeFromTranslatedName(const QString& translatedName);
+  static Type getTypeFromName(const QString& name);
 
   /**
    * Get a translated string for a frame type.
@@ -622,6 +625,20 @@ public:
    */
   static QString getFrameTypeName(Type type);
 
+  /**
+   * Get a display name for a frame name.
+   * @param name frame name as returned by getName()
+   * @return display name, transformed if necessary and translated.
+   */
+  static QString getDisplayName(const QString& name);
+
+  /**
+   * Get a map with display names as keys and frame names as values.
+   * @param names frame names as returned by getName()
+   * @return mapping of display names to frame names.
+   */
+  static QMap<QString, QString> getDisplayNameMap(const QStringList& names);
+
 private:
   friend class TaggedFile;
 
@@ -970,6 +987,21 @@ public:
     return s_quickAccessFrames;
   }
 
+  /**
+   * Create a frame collection from a list of subframe fields.
+   *
+   * The given subframe fields must start with a Frame::ID_Subframe field with
+   * the frame name as its value, followed by the fields of the frame. More
+   * subframes may follow.
+   *
+   * @param begin iterator to begin of subframes
+   * @param end iterator after end of subframes
+   *
+   * @return frames constructed from subframe fields.
+   */
+  static FrameCollection fromSubframes(Frame::FieldList::const_iterator begin,
+                                       Frame::FieldList::const_iterator end);
+
 private:
   /**
    * Search for a frame only by name.
