@@ -78,7 +78,6 @@ public:
    * Create a tagged file.
    *
    * @param key tagged file key
-   * @param dirName directory name
    * @param fileName filename
    * @param idx model index
    * @param features optional tagged file features (TaggedFile::Feature flags)
@@ -88,7 +87,7 @@ public:
    */
   virtual TaggedFile* createTaggedFile(
       const QString& key,
-      const QString& dirName, const QString& fileName,
+      const QString& fileName,
       const QPersistentModelIndex& idx,
       int features = 0) = 0;
 
