@@ -24,29 +24,57 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef QT_NO_DEBUG
-
 #ifndef DEBUGUTILS_H
 #define DEBUGUTILS_H
 
+#include <QObject>
 #include <QModelIndex>
+#include "kid3api.h"
 
 class QAbstractItemModel;
 
 namespace DebugUtils {
 
+/**
+ * Displays information about signals emitted by an object.
+ */
+class KID3_CORE_EXPORT SignalEmissionDumper : public QObject {
+  Q_OBJECT
+public:
+  /**
+   * Constructor.
+   * @param parent parent object
+   */
+  explicit SignalEmissionDumper(QObject* parent = 0);
+
+  /**
+   * Destructor.
+   */
+  virtual ~SignalEmissionDumper();
+
+  /**
+   * Monitor signal emissions of object
+   * @param obj object to monitor
+   */
+  void connectObject(QObject* obj);
+
+private slots:
+  void printSignal();
+};
+
+#ifndef QT_NO_DEBUG
+
 /**
  * Dump an item model.
  * @param model item model to dump
  * @param parent parent model index
  * @param indent number of spaces to indent
  */
-void dumpModel(const QAbstractItemModel& model,
+void KID3_CORE_EXPORT dumpModel(const QAbstractItemModel& model,
                const QModelIndex& parent = QModelIndex(), int indent = 0);
 
+#endif
 
 }
 
 #endif // DEBUGUTILS_H
-
-#endif // QT_NO_DEBUG
