@@ -34,6 +34,7 @@
 #include <QLabel>
 #include <QString>
 #include <QTableView>
+#include "batchimporter.h"
 #include "batchimportsourcedialog.h"
 #include "batchimportconfig.h"
 #include "batchimportsourcesmodel.h"
@@ -183,9 +184,9 @@ BatchImportDialog::BatchImportDialog(const QList<ServerImporter*>& importers,
   destLayout->addWidget(destLabel);
   m_destComboBox = new QComboBox;
   m_destComboBox->setEditable(false);
-  m_destComboBox->addItem(tr("Tag 1"), TrackData::TagV1);
-  m_destComboBox->addItem(tr("Tag 2"), TrackData::TagV2);
-  m_destComboBox->addItem(tr("Tag 1 and Tag 2"), TrackData::TagV2V1);
+  m_destComboBox->addItem(tr("Tag 1"), Frame::TagV1);
+  m_destComboBox->addItem(tr("Tag 2"), Frame::TagV2);
+  m_destComboBox->addItem(tr("Tag 1 and Tag 2"), Frame::TagV2V1);
   destLabel->setBuddy(m_destComboBox);
   destLayout->addWidget(m_destComboBox);
   destLayout->addStretch();
@@ -393,8 +394,9 @@ void BatchImportDialog::setGuiControlsFromProfile()
  */
 void BatchImportDialog::setProfileFromConfig()
 {
-  const QStringList& names = BatchImportConfig::instance().m_profileNames;
-  const QStringList& sources = BatchImportConfig::instance().m_profileSources;
+  const BatchImportConfig& batchImportCfg = BatchImportConfig::instance();
+  const QStringList names = batchImportCfg.profileNames();
+  const QStringList sources = batchImportCfg.profileSources();
 
   m_profiles.clear();
   QStringList::const_iterator namesIt, sourcesIt;
@@ -406,7 +408,7 @@ void BatchImportDialog::setProfileFromConfig()
     profile.setSourcesFromString(*sourcesIt);
     m_profiles.append(profile);
   }
-  m_profileIdx = BatchImportConfig::instance().m_profileIdx;
+  m_profileIdx = batchImportCfg.profileIndex();
   setGuiControlsFromProfile();
 }
 
@@ -418,14 +420,15 @@ void BatchImportDialog::readConfig()
   m_edit->clear();
   setAbortButton(false);
 
-  TrackData::TagVersion importDest = BatchImportConfig::instance().m_importDest;
+  const BatchImportConfig& batchImportCfg = BatchImportConfig::instance();
+  Frame::TagVersion importDest = batchImportCfg.importDest();
   int index = m_destComboBox->findData(importDest);
   m_destComboBox->setCurrentIndex(index);
 
   setProfileFromConfig();
 
-  if (!BatchImportConfig::instance().m_windowGeometry.isEmpty()) {
-    restoreGeometry(BatchImportConfig::instance().m_windowGeometry);
+  if (!batchImportCfg.windowGeometry().isEmpty()) {
+    restoreGeometry(batchImportCfg.windowGeometry());
   }
 }
 
@@ -434,20 +437,20 @@ void BatchImportDialog::readConfig()
  */
 void BatchImportDialog::saveConfig()
 {
-  BatchImportConfig::instance().m_importDest = TrackData::tagVersionCast(
-    m_destComboBox->itemData(m_destComboBox->currentIndex()).toInt());
+  BatchImportConfig& batchImportCfg = BatchImportConfig::instance();
+  batchImportCfg.setImportDest(TrackData::tagVersionCast(
+    m_destComboBox->itemData(m_destComboBox->currentIndex()).toInt()));
 
-  QStringList& names = BatchImportConfig::instance().m_profileNames;
-  QStringList& sources = BatchImportConfig::instance().m_profileSources;
-  names.clear();
-  sources.clear();
+  QStringList names, sources;
   setProfileFromGuiControls();
   foreach (const BatchImportProfile& profile, m_profiles) {
     names.append(profile.getName());
     sources.append(profile.getSourcesAsString());
   }
-  BatchImportConfig::instance().m_profileIdx = m_profileComboBox->currentIndex();
-  BatchImportConfig::instance().m_windowGeometry = saveGeometry();
+  batchImportCfg.setProfileNames(names);
+  batchImportCfg.setProfileSources(sources);
+  batchImportCfg.setProfileIndex(m_profileComboBox->currentIndex());
+  batchImportCfg.setWindowGeometry(saveGeometry());
 }
 
 /**
@@ -460,47 +463,46 @@ void BatchImportDialog::showHelp()
 
 /**
  * Show information about import event.
- * @param type import event type
+ * @param type import event type, enum BatchImporter::ImportEventType
  * @param text text to display
  */
-void BatchImportDialog::showImportEvent(BatchImportProfile::ImportEventType type,
-                                        const QString& text)
+void BatchImportDialog::showImportEvent(int type, const QString& text)
 {
   QString eventText;
   switch (type) {
-  case BatchImportProfile::ReadingDirectory:
+  case BatchImporter::ReadingDirectory:
     setAbortButton(true);
     eventText = tr("Reading Directory");
     break;
-  case BatchImportProfile::Started:
+  case BatchImporter::Started:
     setAbortButton(true);
     eventText = tr("Started");
     break;
-  case BatchImportProfile::SourceSelected:
+  case BatchImporter::SourceSelected:
     eventText = tr("Source");
     break;
-  case BatchImportProfile::QueryingAlbumList:
+  case BatchImporter::QueryingAlbumList:
     eventText = tr("Querying");
     break;
-  case BatchImportProfile::FetchingTrackList:
-  case BatchImportProfile::FetchingCoverArt:
+  case BatchImporter::FetchingTrackList:
+  case BatchImporter::FetchingCoverArt:
     eventText = tr("Fetching");
     break;
-  case BatchImportProfile::TrackListReceived:
+  case BatchImporter::TrackListReceived:
     eventText = tr("Data received");
     break;
-  case BatchImportProfile::CoverArtReceived:
+  case BatchImporter::CoverArtReceived:
     eventText = tr("Cover");
     break;
-  case BatchImportProfile::Finished:
+  case BatchImporter::Finished:
     setAbortButton(false);
     eventText = tr("Finished");
     break;
-  case BatchImportProfile::Aborted:
+  case BatchImporter::Aborted:
     setAbortButton(false);
     eventText = tr("Aborted");
     break;
-  case BatchImportProfile::Error:
+  case BatchImporter::Error:
     eventText = tr("Error");
   }
   if (!text.isEmpty()) {
