@@ -39,10 +39,18 @@ class QComboBox;
 class QLineEdit;
 class QSpinBox;
 class QStringListModel;
+class QStandardItemModel;
 class FormatBox;
 class ConfigTable;
 class CommandsTableModel;
 class CheckableStringListModel;
+class FormatConfig;
+class TagConfig;
+class FileConfig;
+class UserActionsConfig;
+class GuiConfig;
+class NetworkConfig;
+class ImportConfig;
 
 /**
  * Pages for configuration dialog.
@@ -100,7 +108,22 @@ public:
    */
   void getConfig() const;
 
+public slots:
+  /**
+   * Set values in pages from default configuration.
+   */
+  void setDefaultConfig();
+
 private:
+  /**
+   * Set values in dialog from given configurations.
+   */
+  void setConfigs(
+      const FormatConfig& fnCfg, const FormatConfig& id3Cfg,
+      const TagConfig& tagCfg, const FileConfig& fileCfg,
+      const UserActionsConfig& userActionsCfg, const GuiConfig& guiCfg,
+      const NetworkConfig& networkCfg, const ImportConfig& importCfg);
+
   /** Load last-opened files checkbox */
   QCheckBox* m_loadLastOpenedFileCheckBox;
   /** Preserve timestamp checkbox */
@@ -140,7 +163,7 @@ private:
   /** Model with list of custom genres */
   QStringListModel* m_genresEditModel;
   /** Model with standard tags selection */
-  CheckableStringListModel* m_quickAccessTagsModel;
+  QStandardItemModel* m_quickAccessTagsModel;
   /** Play on double click checkbox */
   QCheckBox* m_playOnDoubleClickCheckBox;
   /** Commands table */
