@@ -83,6 +83,7 @@ QList<int> checkableFrameTypes() {
  * @param platformTools platform tools
  * @param parent        parent widget
  * @param caption       dialog title
+ * @param genreModel    genre model
  * @param trackDataModel track data to be filled with imported values,
  *                      is passed with durations of files set
  * @param importers     server importers
@@ -91,6 +92,7 @@ QList<int> checkableFrameTypes() {
 ImportDialog::ImportDialog(IPlatformTools* platformTools,
                            QWidget* parent, QString& caption,
                            TrackDataModel* trackDataModel,
+                           GenreModel* genreModel,
                            const QList<ServerImporter*>& importers,
                            const QList<ServerTrackImporter*>& trackImporters) :
   QDialog(parent), m_platformTools(platformTools),
@@ -115,7 +117,7 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   m_trackDataTable->resizeColumnsToContents();
   m_trackDataTable->setItemDelegateForColumn(
         m_trackDataModel->columnForFrameType(Frame::FT_Genre),
-        new FrameItemDelegate(this));
+        new FrameItemDelegate(genreModel, this));
 #if QT_VERSION >= 0x050000
   m_trackDataTable->verticalHeader()->setSectionsMovable(true);
   m_trackDataTable->horizontalHeader()->setSectionsMovable(true);
@@ -142,8 +144,8 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   QLabel* coverArtLabel = new QLabel(tr("Cover Art:"));
   accuracyLayout->addWidget(coverArtLabel);
   m_coverArtUrlLabel = new QLabel(QLatin1String(" -"));
-  accuracyLayout->addWidget(m_coverArtUrlLabel);
-  accuracyLayout->addStretch();
+  m_coverArtUrlLabel->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Preferred);
+  accuracyLayout->addWidget(m_coverArtUrlLabel, 1);
   vlayout->addLayout(accuracyLayout);
 
   QHBoxLayout* butlayout = new QHBoxLayout;
@@ -177,9 +179,9 @@ ImportDialog::ImportDialog(IPlatformTools* platformTools,
   butlayout->addWidget(destLabel);
   m_destComboBox = new QComboBox;
   m_destComboBox->setEditable(false);
-  m_destComboBox->addItem(tr("Tag 1"), TrackData::TagV1);
-  m_destComboBox->addItem(tr("Tag 2"), TrackData::TagV2);
-  m_destComboBox->addItem(tr("Tag 1 and Tag 2"), TrackData::TagV2V1);
+  m_destComboBox->addItem(tr("Tag 1"), Frame::TagV1);
+  m_destComboBox->addItem(tr("Tag 2"), Frame::TagV2);
+  m_destComboBox->addItem(tr("Tag 1 and Tag 2"), Frame::TagV2V1);
   destLabel->setBuddy(m_destComboBox);
   butlayout->addWidget(m_destComboBox);
   QToolButton* revertButton = new QToolButton;
@@ -391,20 +393,21 @@ void ImportDialog::showWithSubDialog(int importerIndex)
  */
 void ImportDialog::clear()
 {
-  m_serverComboBox->setCurrentIndex(ImportConfig::instance().m_importServer);
-  TrackData::TagVersion importDest = ImportConfig::instance().m_importDest;
+  const ImportConfig& importCfg = ImportConfig::instance();
+  m_serverComboBox->setCurrentIndex(importCfg.importServer());
+  Frame::TagVersion importDest = importCfg.importDest();
   int index = m_destComboBox->findData(importDest);
   m_destComboBox->setCurrentIndex(index);
-  if (importDest == TrackData::TagV1 &&
+  if (importDest == Frame::TagV1 &&
       !m_trackDataModel->trackData().isTagV1Supported()) {
-    index = m_destComboBox->findData(TrackData::TagV2);
+    index = m_destComboBox->findData(Frame::TagV2);
     m_destComboBox->setCurrentIndex(index);
     changeTagDestination();
   }
 
-  m_mismatchCheckBox->setChecked(ImportConfig::instance().m_enableTimeDifferenceCheck);
-  m_maxDiffSpinBox->setValue(ImportConfig::instance().m_maxTimeDifference);
-  m_columnVisibility = ImportConfig::instance().m_importVisibleColumns;
+  m_mismatchCheckBox->setChecked(importCfg.enableTimeDifferenceCheck());
+  m_maxDiffSpinBox->setValue(importCfg.maxTimeDifference());
+  m_columnVisibility = importCfg.importVisibleColumns();
 
   foreach (int frameType, checkableFrameTypes()) {
     if (frameType < 64) {
@@ -416,8 +419,8 @@ void ImportDialog::clear()
     }
   }
 
-  if (!ImportConfig::instance().m_importWindowGeometry.isEmpty()) {
-    restoreGeometry(ImportConfig::instance().m_importWindowGeometry);
+  if (!importCfg.importWindowGeometry().isEmpty()) {
+    restoreGeometry(importCfg.importWindowGeometry());
   }
 
   showPreview();
@@ -440,8 +443,8 @@ void ImportDialog::showPreview()
   int accuracy = m_trackDataModel->calculateAccuracy();
   m_accuracyPercentLabel->setText(accuracy >= 0 && accuracy <= 100
                                   ? QString::number(accuracy) + QLatin1Char('%') : QLatin1String("-"));
-  QString coverArtUrl = m_trackDataModel->getTrackData().getCoverArtUrl();
-  m_coverArtUrlLabel->setText(coverArtUrl.isEmpty() ? QLatin1String("-") : coverArtUrl);
+  QUrl coverArtUrl = m_trackDataModel->getTrackData().getCoverArtUrl();
+  m_coverArtUrlLabel->setText(coverArtUrl.isEmpty() ? QLatin1String("-") : coverArtUrl.toString());
 }
 
 /**
@@ -462,7 +465,7 @@ void ImportDialog::onServerImportDialogClosed()
  *
  * @return TagV1, TagV2 or TagV2V1 for ID3v1, ID3v2 or both.
  */
-TrackData::TagVersion ImportDialog::getDestination() const
+Frame::TagVersion ImportDialog::getDestination() const
 {
   return TrackData::tagVersionCast(
     m_destComboBox->itemData(m_destComboBox->currentIndex()).toInt());
@@ -481,15 +484,19 @@ void ImportDialog::showHelp()
  */
 void ImportDialog::saveConfig()
 {
-  ImportConfig::instance().m_importDest = TrackData::tagVersionCast(
-    m_destComboBox->itemData(m_destComboBox->currentIndex()).toInt());
+  ImportConfig& importCfg = ImportConfig::instance();
+  importCfg.setImportDest(TrackData::tagVersionCast(
+    m_destComboBox->itemData(m_destComboBox->currentIndex()).toInt()));
 
-  ImportConfig::instance().m_importServer = m_serverComboBox->currentIndex();
-  getTimeDifferenceCheck(ImportConfig::instance().m_enableTimeDifferenceCheck,
-                         ImportConfig::instance().m_maxTimeDifference);
-  ImportConfig::instance().m_importVisibleColumns = m_columnVisibility;
+  importCfg.setImportServer(m_serverComboBox->currentIndex());
+  bool enable;
+  int maxDiff;
+  getTimeDifferenceCheck(enable, maxDiff);
+  importCfg.setEnableTimeDifferenceCheck(enable);
+  importCfg.setMaxTimeDifference(maxDiff);
+  importCfg.setImportVisibleColumns(m_columnVisibility);
 
-  ImportConfig::instance().m_importWindowGeometry = saveGeometry();
+  importCfg.setImportWindowGeometry(saveGeometry());
 }
 
 /**
