@@ -100,21 +100,20 @@ public:
 
   /**
    * Let user select a frame type.
+   * frameSelected() is emitted when the edit dialog is closed with the selected
+   * frame as a parameter if a frame is selected.
    *
-   * @param frame is filled with the selected frame if true is returned
+   * @param frame is filled with the selected frame
    * @param taggedFile tagged file for which frame has to be selected
-   *
-   * @return false if no frame selected.
    */
-  virtual bool selectFrame(Frame* frame, const TaggedFile* taggedFile);
+  virtual void selectFrame(Frame* frame, const TaggedFile* taggedFile);
 
   /**
-   * Return object which emits frameEdited() signal.
+   * Return object which emits frameSelected(), frameEdited() signals.
    *
-   * @return object which emits frameEdited() when dialog is closed, its
-   * parameter is true if the dialog is accepted.
+   * @return object which emits signals.
    */
-  virtual QObject* frameEditedEmitter();
+  virtual QObject* qobject();
 
   /**
    * Set back pointer for implementation class.
@@ -148,12 +147,6 @@ public:
    */
   void openRecentDirectory(const QString& dir);
 
-  /**
-   * Set window title with information from directory, filter and modification
-   * state.
-   */
-  void updateWindowCaption();
-
   /**
    * Apply configuration changes.
    */
@@ -172,6 +165,12 @@ public:
   Kid3Form* form() { return m_form; }
 
 public slots:
+  /**
+   * Set window title with information from directory, filter and modification
+   * state.
+   */
+  void updateWindowCaption();
+
   /**
    * Open directory, user has to confirm if current directory modified.
    *
@@ -321,6 +320,12 @@ signals:
    */
   void frameEdited(const Frame* frame);
 
+  /**
+   * Emitted when the dialog to select a frame is closed.
+   * @param frame selected frame if dialog was accepted, else 0
+   */
+  void frameSelected(const Frame* frame);
+
 private slots:
   /**
    * Update ID3v2 tags in GUI controls from file displayed in frame list.
@@ -329,11 +334,6 @@ private slots:
    */
   void updateAfterFrameModification(TaggedFile* taggedFile);
 
-  /**
-   * Update modification state, caption and listbox entries.
-   */
-  void updateModificationState();
-
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Show play tool bar.
@@ -468,6 +468,7 @@ private:
   TaggedFile* m_editFrameTaggedFile;
   QDateTime m_expandFileListStartTime;
   bool m_findReplaceActive;
+  bool m_expandNotificationNeeded;
 };
 
 
@@ -481,7 +482,7 @@ private:
  * already a QObject), most of its functionality is delegated to a QObject
  * implementation class.
  */
-class KID3_GUI_EXPORT BaseMainWindow : public IFrameEditor {
+class KID3_GUI_EXPORT BaseMainWindow {
 public:
   /**
    * Constructor.
@@ -540,36 +541,6 @@ public:
    */
   virtual void setWindowCaption(const QString& caption, bool modified) = 0;
 
-  /**
-   * Create dialog to edit a frame and update the fields
-   * if Ok is returned.
-   * frameEdited() is emitted when the edit dialog is closed with the edited
-   * frame as a parameter if it was accepted.
-   *
-   * @param frame frame to edit
-   * @param taggedFile tagged file where frame has to be set
-   */
-  virtual void editFrameOfTaggedFile(const Frame* frame,
-                                     TaggedFile* taggedFile);
-
-  /**
-   * Let user select a frame type.
-   *
-   * @param frame is filled with the selected frame if true is returned
-   * @param taggedFile tagged file for which frame has to be selected
-   *
-   * @return false if no frame selected.
-   */
-  virtual bool selectFrame(Frame* frame, const TaggedFile* taggedFile);
-
-  /**
-   * Return object which emits frameEdited() signal.
-   *
-   * @return object which emits frameEdited() when dialog is closed, its
-   * parameter is the edited frame the dialog is accepted.
-   */
-  virtual QObject* frameEditedEmitter();
-
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Play audio file.
