@@ -30,7 +30,6 @@
 #include <QString>
 #include <QTextCodec>
 #include <QByteArray>
-#include <QCoreApplication>
 #include <QtEndian>
 
 #include <cstring>
@@ -174,6 +173,7 @@ bool Mp3File::writeTags(bool force, bool* renamed, bool preserve)
 {
   QString fnStr(currentFilePath());
   if (isChanged() && !QFileInfo(fnStr).isWritable()) {
+    revertChangedFilename();
     return false;
   }
 
@@ -685,7 +685,7 @@ static bool setGenreNum(ID3_Tag* tag, int num)
     if (num != 0xff) {
       str = QString(QLatin1String("(%1)")).arg(num);
     } else {
-      str.clear();
+      str = QLatin1String("");
     }
     changed = getTextField(tag, ID3FID_CONTENTTYPE) != str &&
               setTextField(tag, ID3FID_CONTENTTYPE, str);
@@ -1967,17 +1967,14 @@ bool Mp3File::setFrameV2(const Frame& frame)
   return TaggedFile::setFrameV2(frame);
 }
 
-
 /**
- * Add a frame in the tags 2.
- *
- * @param frame frame to add, a field list may be added by this method
- *
- * @return true if ok.
+ * Create an id3lib frame from a frame.
+ * @param frame frame
+ * @return id3lib frame, 0 if invalid.
  */
-bool Mp3File::addFrameV2(Frame& frame)
+ID3_Frame* Mp3File::createId3FrameFromFrame(Frame& frame) const
 {
-  // Add a new frame.
+  ID3_Frame* id3Frame = 0;
   ID3_FrameID id;
   if (frame.getType() != Frame::FT_Other) {
     id = getId3libFrameIdForType(frame.getType());
@@ -1995,8 +1992,8 @@ bool Mp3File::addFrameV2(Frame& frame)
       }
     }
   }
-  if (id != ID3FID_NOFRAME && id != ID3FID_SETSUBTITLE && m_tagV2) {
-    ID3_Frame* id3Frame = new ID3_Frame(id);
+  if (id != ID3FID_NOFRAME && id != ID3FID_SETSUBTITLE) {
+    id3Frame = new ID3_Frame(id);
     ID3_Field* fld = id3Frame->GetField(ID3FN_TEXT);
     if (fld) {
       ID3_TextEnc enc = getDefaultTextEncoding();
@@ -2076,8 +2073,24 @@ bool Mp3File::addFrameV2(Frame& frame)
     Frame::Type type;
     const char* name;
     getTypeStringForId3libFrameId(id, type, name);
-    m_tagV2->AttachFrame(id3Frame);
     frame.setExtendedType(Frame::ExtendedType(type, QString::fromLatin1(name)));
+  }
+  return id3Frame;
+}
+
+/**
+ * Add a frame in the tags 2.
+ *
+ * @param frame frame to add, a field list may be added by this method
+ *
+ * @return true if ok.
+ */
+bool Mp3File::addFrameV2(Frame& frame)
+{
+  // Add a new frame.
+  ID3_Frame* id3Frame;
+  if (m_tagV2 && (id3Frame = createId3FrameFromFrame(frame)) != 0) {
+    m_tagV2->AttachFrame(id3Frame);
     frame.setIndex(m_tagV2->NumFrames() - 1);
     if (frame.fieldList().empty()) {
       // add field list to frame
@@ -2293,6 +2306,23 @@ void Mp3File::getAllFramesV2(FrameCollection& frames)
   frames.addMissingStandardFrames();
 }
 
+/**
+ * Add a suitable field list for the frame if missing.
+ * If a frame is created, its field list is empty. This method will create
+ * a field list appropriate for the frame type and tagged file type if no
+ * field list exists.
+ * @param frame frame where field list is added
+ */
+void Mp3File::addFieldList(Frame& frame) const
+{
+  if (frame.fieldList().isEmpty()) {
+    ID3_Frame* id3Frame = createId3FrameFromFrame(frame);
+    getFieldsFromId3Frame(id3Frame, frame.fieldList());
+    frame.setFieldListFromValue();
+    delete id3Frame;
+  }
+}
+
 /**
  * Get a list of frame IDs which can be added.
  *
@@ -2304,14 +2334,14 @@ QStringList Mp3File::getFrameIds() const
   for (int type = Frame::FT_FirstFrame; type <= Frame::FT_LastFrame; ++type) {
     if (type != Frame::FT_Part) {
       lst.append(Frame::ExtendedType(static_cast<Frame::Type>(type), QLatin1String("")).
-                 getTranslatedName());
+                 getName());
     }
   }
   for (int i = 0; i <= ID3FID_WWWUSER; ++i) {
     if (typeStrOfId[i].type == Frame::FT_Other) {
       const char* s = typeStrOfId[i].str;
       if (s) {
-        lst.append(QCoreApplication::translate("@default", s));
+        lst.append(QString::fromLatin1(s));
       }
     }
   }
