@@ -221,6 +221,18 @@ public:
   Q_INVOKABLE static bool setEnv(const QByteArray& varName,
                                  const QByteArray& value);
 
+  /**
+   * Get version of Kid3.
+   * @return Kid3 version string, e.g. "3.3.0".
+   */
+  Q_INVOKABLE static QString getKid3Version();
+
+  /**
+   * Get release year of Kid3.
+   * @return Kid3 year string, e.g. "2015".
+   */
+  Q_INVOKABLE static QString getKid3ReleaseYear();
+
   /**
    * Get version of Qt.
    * @return Qt version string, e.g. "5.4.1".
