@@ -302,13 +302,13 @@ void MusicBrainzImporter::parseAlbumResults(const QByteArray& albumStr)
     }
 
     ImportTrackDataVector trackDataVector(m_trackDataModel->getTrackData());
-    trackDataVector.setCoverArtUrl(QString());
+    trackDataVector.setCoverArtUrl(QUrl());
     const bool coverArt = getCoverArt();
     if (coverArt) {
       QString asin(release.namedItem(QLatin1String("asin")).toElement().text());
       if (!asin.isEmpty()) {
         trackDataVector.setCoverArtUrl(
-          QLatin1String("http://www.amazon.com/dp/") + asin);
+          QUrl(QLatin1String("http://www.amazon.com/dp/") + asin));
       }
     }
 
@@ -357,7 +357,7 @@ void MusicBrainzImporter::parseAlbumResults(const QByteArray& albumStr)
                       QString type(relation.attribute(QLatin1String("type")));
                       if (type == QLatin1String("cover art link") || type == QLatin1String("amazon asin")) {
                         trackDataVector.setCoverArtUrl(
-                          relation.namedItem(QLatin1String("target")).toElement().text());
+                          QUrl(relation.namedItem(QLatin1String("target")).toElement().text()));
                       }
                     }
                   }
@@ -551,16 +551,16 @@ void MusicBrainzImporter::sendTrackListQuery(
   path += QLatin1Char('/');
   path += id;
   path += QLatin1String("?inc=");
-  if (cfg->m_additionalTags) {
+  if (cfg->additionalTags()) {
     path += QLatin1String("artist-credits+labels+recordings+media+isrcs+"
                 "discids+artist-rels+label-rels+recording-rels+release-rels");
   } else {
     path += QLatin1String("artists+recordings");
   }
-  if (cfg->m_coverArt) {
+  if (cfg->coverArt()) {
     path += QLatin1String("+url-rels");
   }
-  if (cfg->m_additionalTags) {
+  if (cfg->additionalTags()) {
     path += QLatin1String("+work-rels+recording-level-rels+work-level-rels");
   }
   sendRequest(QLatin1String("musicbrainz.org:80"), path);
