@@ -45,12 +45,9 @@ public:
   /**
    * Constructor.
    *
-   * @param dn directory name
-   * @param fn filename
-   * @param idx model index
+   * @param idx index in file proxy model
    */
-  FlacFile(const QString& dn, const QString& fn,
-           const QPersistentModelIndex& idx);
+  explicit FlacFile(const QPersistentModelIndex& idx);
 
   /**
    * Destructor.
@@ -160,24 +157,13 @@ private:
   FlacFile(const FlacFile&);
   FlacFile& operator=(const FlacFile&);
 
-  /** Information about a FLAC file. */
-  struct FileInfo {
-    FileInfo() : channels(0), sampleRate(0), bitrate(0),
-      duration(0), valid(false) {}
-
-    /**
-     * Read information about a FLAC file.
-     * @param si stream info
-     * @return true if ok.
-     */
-    bool read(FLAC::Metadata::StreamInfo* si);
-
-    unsigned channels;      /**< number of channels */
-    unsigned sampleRate;    /**< sample rate in Hz */
-    unsigned long bitrate;  /**< bitrate in bits/s */
-    unsigned long duration; /**< duration in seconds */
-    bool valid;             /**< true if read() was successful */
-  };
+  /**
+   * Read information about a FLAC file.
+   * @param info file info to fill
+   * @param si stream info
+   * @return true if ok.
+   */
+  bool readFileInfo(FileInfo& info, FLAC::Metadata::StreamInfo* si) const;
 
   /**
    * Set the vorbis comment block with the comments.
@@ -192,9 +178,6 @@ private:
   PictureList m_pictures;
 #endif // HAVE_FLAC_PICTURE
 
-  /** Info about file. */
-  FileInfo m_fileInfo;
-
   /** FLAC metadata chain. */
   FLAC::Metadata::Chain* m_chain;
 };
